---
title: Nushell 0.33
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing 0.33 of Nu. This release includes improved completions, support for pipeline variables, syntax theming and more.
---

# Nushell 0.33

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your commandline. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful commandline pipelines.

Today, we're releasing 0.33 of Nu. This release includes improved completions, support for pipeline variables, syntax theming and more.

<!-- more -->

# Where to get it

Nu 0.33 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.33.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

If you want all the goodies, you can install `cargo install nu --features=extra`.

If you'd like to try the experimental paging feature in this release, you can install with `cargo install nu --features=table-pager`.

As part of this release, we also publish a set of plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# What's New

## Improved completions (fdncred, NiklasJonsson, kubouch, andrasio, jt)

We've begun the completion improvements that have been planned for some time. In this release, we've added completions for [alias definitions](https://github.com/nushell/nushell/pull/3594), [source imports](https://github.com/nushell/nushell/pull/3589), completions for [quoted paths](https://github.com/nushell/nushell/pull/3577), completions while [inside of a pipeline](https://github.com/nushell/nushell/pull/3575), completions in [incomplete expressions](https://github.com/nushell/nushell/pull/3564), [subcommand completions](https://github.com/nushell/nushell/pull/3571) and more.

On Windows, we've [sped up path completions](https://github.com/nushell/nushell/pull/3665). We've also reworked path handling, which should help make [path completions in Windows more consistent](https://github.com/nushell/nushell/pull/3653), including handling of `~`.

Behind the scenes, we've also refactored completions into their own crate, so that we can more easily grow the areas where completions are supported.

## Pipeline vars (jt)

Sometimes, when you're working on a pipeline, you want to refer to values coming in using an xargs style. With 0.33, we've introduced a new built-in variable called `$in`. The `$in` variable will collect the pipeline into a value for you, allowing you to access the whole stream as a parameter.

```shell
> echo 1 2 3 | $in.1 * $in.2
6
```

## New distributions (itsme-alan, zmedico)

You can now install Nushell from the [winget repo](https://github.com/microsoft/winget-pkgs/pull/17428) and from [gentoo](https://packages.gentoo.org/packages/app-shells/nushell).

## More natural pipeline output (jt)

In this release, we've also relaxed some of the strictness in when output happens to always be at the end of a pipeline. In previous versions of Nushell, it was common for people to try an example like `echo "hello "; echo "world"` only to be confused why they only saw `world` in the output. Now, we treat `;` like carriage return, so that pipelines more naturally output their results just as they do at the end of lines.

You can add back in the ignore ability using the new `ignore` command, which will ignore any stdout or data output from the previous command in the pipeline. For example, `ls | ignore`.

## Syntax highlighting themes (fdncred)

![image of syntax highlighting themes in Nushell](../assets/images/0_32_themes.png)

_Nu, with configurable colors_

You can now configure the colors used in syntax highlighting. For the currently supported token types and examples, check out [the original PR](https://github.com/nushell/nushell/pull/3606).

## New commands

- nathom added [`unlet_env` to remove environment variables from the current scope](https://github.com/nushell/nushell/pull/3629)
- jt added the [`ignore` command to ignore pipeline output](https://github.com/nushell/nushell/pull/3643)
- fdncred added [`ansi gradient` command](https://github.com/nushell/nushell/pull/3570)

## Additional improvements

- fdncred added [path and environment path separators to `char`](https://github.com/nushell/nushell/pull/3660) to allow for creating more portable scripts, fixed an issue with [error colors](https://github.com/nushell/nushell/pull/3634), added [single and double quote to char](https://github.com/nushell/nushell/pull/3601), [version now lists plugins](https://github.com/nushell/nushell/pull/3548)
- efx updated [commands to engine-p style](https://github.com/nushell/nushell/pull/3649)
- chrisfinazzo [fixed some of our helper scripts](https://github.com/nushell/nushell/pull/3635)
- andrasio, jt [removed the clap dependency, so nushell parses its own parameters](https://github.com/nushell/nushell/pull/3632)
- vladdoster landed [some doc improvements](https://github.com/nushell/nushell/pull/3630)
- NiklasJonsson improved [nu doc comments](https://github.com/nushell/nushell/pull/3628)
- reaganmcf added [an optional plugin for handling mp4 metadata](https://github.com/nushell/nushell/pull/3618) and [bumped sysinfo](https://github.com/nushell/nushell/pull/3561)
- voanhduy1512 added support for [invoking external commands via string interpolation](https://github.com/nushell/nushell/pull/3611)
- Garfield96 added [--sheets for xlsx/ods](https://github.com/nushell/nushell/pull/3600), [--tables for `from sqlite`](https://github.com/nushell/nushell/pull/3529), and [fixed a panic with giving empty tables to `to sqlite`](https://github.com/nushell/nushell/pull/3522)
- kubouch improved [errors and updated commands to engine-p](https://github.com/nushell/nushell/pull/3588), improved some [internal handling of `def`](https://github.com/nushell/nushell/pull/3580), [clarified the `exec` help message](https://github.com/nushell/nushell/pull/3588)
- sholderbach improved [`where` docs](https://github.com/nushell/nushell/pull/3573)
- jt added [parsing for hex, binary, and octal numbers](https://github.com/nushell/nushell/pull/3562)
- pka improved [territory in locale support for byte formatting](https://github.com/nushell/nushell/pull/3560)
- ahkrr fixed handling of [# in filenames](https://github.com/nushell/nushell/pull/3524)
- jt, LovecraftianHorror, apatrushev, sholderbach, elferherrera, inet56 added fixes to the website and docs
- fdncred, efx, jt, and andrasio all added scripts and fixes to the scripts repo

# Looking ahead

We're continuing to improve our dataframe support, and hope to be rolling it out a part of the default commands in the next release. Elfherrera has been [hard at work improving the dataframe support to get it ready](https://github.com/nushell/nushell/pull/3608).
