---
title: Nushell 0.65
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.65 of Nu. This release includes better support for binary data, a new way of checking source files for correctness, improved command unification, and more.
---

# Nushell 0.65

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your commandline. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful commandline pipelines.

Today, we're releasing version 0.65 of Nu. This release includes better support for binary data, a new way of checking source files for correctness, improved command unification, and more.

<!-- more -->

# Where to get it

Nu 0.65 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.65.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

If you want all the built-in goodies, you can install `cargo install nu --features=extra`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release

## Better support for binary data (hustcer, jt, CBenoit)

Binary support in Nushell has steadily improved, and in this release, it's gotten a strong push forward. New features include:

- New operators `bit-and`, `bit-or`, `bit-xor`, as well as renamed `bit-shl` and `bit-shr`. These correspond to bitwise and, or, exclusive or, shift left, and shift right.
- A new `encode` command as well as binary support for `hash`
- Improved binary support for `skip` and `take`.

## Nu-check (Kangaxx-0)

Starting with this release, Nushell now provides a `nu-check` command which can do a check over a source file for potential parsing and typechecking errors. This will make it easier for script authors to check their scripts without running them. In the future, this may also be an easy way for editors to check a script and return errors during editing.

## Unification continues (elferherrera)

In 0.65, we've also continued the process to unify commands for different datatypes. In this release, `db` and mysql support has simplified, bringing it closer to the already existing dataframe support.

Before:

```
open myfile.db
| db select a
| db from table_1
| db where ((db col a) > 1 | db and ((db col a) < 10))
```

Now:

```
open myfile.db
| select a
| from table_1
| where ((field a) > 1 | and ((field a) < 10))
```

Like the dataframe support, this is built on the new support to overload commands based on their input type. This will allow Nushell to have a nice, uniform syntax that just works over a variety of data types in the future.

## Additional new commands

You can now use the `port` command to find the next available port. (WindSoilder)

# Looking ahead

With 0.65, Nushell continues to move towards a more polished, more full-featured language that can handle a wider range of datatypes well. We're continuing to work towards this goal and find ways to continue to unify the language, allowing you to learn one language and apply that knowledge to many types of data.

# Full changelog

## Nushell

- sholderbach created [Pin reedline to new 0.8.0 release](https://github.com/nushell/nushell/pull/5954)
- jt created [bump to 0.65](https://github.com/nushell/nushell/pull/5952), and [Fix 'skip' support for binary streams](https://github.com/nushell/nushell/pull/5943), and [Make `take` work like `first`](https://github.com/nushell/nushell/pull/5942), and [Binary into int](https://github.com/nushell/nushell/pull/5941), and [Rename bitwise operators for readability](https://github.com/nushell/nushell/pull/5937), and [Move input/output type from Command to Signature](https://github.com/nushell/nushell/pull/5880), and [Clippy and remove unused is_binary](https://github.com/nushell/nushell/pull/5879), and [Bump to 0.64.1 dev version](https://github.com/nushell/nushell/pull/5865)
- WindSoilder created [add bytes starts-with command](https://github.com/nushell/nushell/pull/5950), and [add bytes length command](https://github.com/nushell/nushell/pull/5945), and [add -e flag to print, to print the value to stderr](https://github.com/nushell/nushell/pull/5935), and [change default keybinding in default config](https://github.com/nushell/nushell/pull/5925), and [make module imports in scripts used for relative path.](https://github.com/nushell/nushell/pull/5913), and [make path exists work on expanded path](https://github.com/nushell/nushell/pull/5886), and [simplify error make](https://github.com/nushell/nushell/pull/5883), and [fix plugin path with whitespace](https://github.com/nushell/nushell/pull/5871), and [Port command](https://github.com/nushell/nushell/pull/5849), and [fix exit code](https://github.com/nushell/nushell/pull/5835), and [add notes for def_env](https://github.com/nushell/nushell/pull/5807), and [add light theme to default_config](https://github.com/nushell/nushell/pull/5804)
- hustcer created [Add bit operator: `bit-xor`](https://github.com/nushell/nushell/pull/5940), and [Add `band` and `bor` operator for bit operations](https://github.com/nushell/nushell/pull/5936), and [Update #4202: Add shift operator bshl and bshr for integers](https://github.com/nushell/nushell/pull/5928), and [Add an example for `default` command to get an env var with fallback](https://github.com/nushell/nushell/pull/5874), and [Fix less.exe downloading for windows release pkgs, close #5868](https://github.com/nushell/nushell/pull/5873), and [feat: Update dockerfile for latest nu release](https://github.com/nushell/nushell/pull/5843)
- merelymyself created [add search terms for `is-admin`](https://github.com/nushell/nushell/pull/5939), and [ensure `required` positionals don't show up as `optional` when `help`](https://github.com/nushell/nushell/pull/5916), and [Better error handling using `do`](https://github.com/nushell/nushell/pull/5890), and [Errors when `let in`, `let env` and similar commands are passed.](https://github.com/nushell/nushell/pull/5866), and [Finish git fetch custom completions to allow for completing branch](https://github.com/nushell/nushell/pull/5859), and [Prevents duplicate fields in `transpose -r`](https://github.com/nushell/nushell/pull/5840), and [Calculate history duration properly (sqlite)](https://github.com/nushell/nushell/pull/5827), and [Fixes `to nuon` for `inf`, `-inf`, and `NaN`](https://github.com/nushell/nushell/pull/5818), and [Attempts to fix file completions for `open`, `rm` and `ls` (and other filesystem commands)](https://github.com/nushell/nushell/pull/5805)
- IsaacKhor created [Change C-u and C-k to be readline compatible, move old C-u to C-s](https://github.com/nushell/nushell/pull/5938)
- nibon7 created [Fix `to md --pretty` when rendering a list](https://github.com/nushell/nushell/pull/5932), and [Return error when external command core dumped](https://github.com/nushell/nushell/pull/5908), and [Fix drop nth with open end range on 32-bit platforms](https://github.com/nushell/nushell/pull/5808)
- fdncred created [fix parse_failure_due_conflicted_flags test](https://github.com/nushell/nushell/pull/5926), and [fix bug where `thin` theme wasn't getting applied correctly](https://github.com/nushell/nushell/pull/5905), and [fix excessive ansi escape sequences](https://github.com/nushell/nushell/pull/5901), and [update encode decode with new signature](https://github.com/nushell/nushell/pull/5881), and [add ability to convert timestamp_millis()](https://github.com/nushell/nushell/pull/5876), and [cleanup `$config` as a built-in](https://github.com/nushell/nushell/pull/5852), and [update reedline config based on recent reedline changes](https://github.com/nushell/nushell/pull/5845), and [first stab at minimizing ansi escapes](https://github.com/nushell/nushell/pull/5822), and [add more columns to the history command when using sqlite history](https://github.com/nushell/nushell/pull/5817)
- stormasm created [update crate thiserror to version 1.0.31 in four crates](https://github.com/nushell/nushell/pull/5919), and [Move the history and tutor commands out of core_commands](https://github.com/nushell/nushell/pull/5813)
- Kangaxx-0 created [Add all flag to nu-check command](https://github.com/nushell/nushell/pull/5911), and [Introduce new command - nu check](https://github.com/nushell/nushell/pull/5864), and [Remove external nu from nu config](https://github.com/nushell/nushell/pull/5847), and [Add more tests for completion](https://github.com/nushell/nushell/pull/5826), and [Fix alias completion crash](https://github.com/nushell/nushell/pull/5814)
- Yethal created [Slim down Dockerfile](https://github.com/nushell/nushell/pull/5910)
- CBenoit created [docs: clarify `print` and `echo` commands](https://github.com/nushell/nushell/pull/5909), and [build: update `miette` dependency](https://github.com/nushell/nushell/pull/5889), and [feat: add `--binary(-b)` option to `hash` commands](https://github.com/nushell/nushell/pull/5885), and [Deprecate `hash base64`, extend `decode` and add `encode` commands](https://github.com/nushell/nushell/pull/5863)
- elferherrera created [Header filtering out of for loop](https://github.com/nushell/nushell/pull/5896), and [Dataframe with real index](https://github.com/nushell/nushell/pull/5892), and [Remove extra print](https://github.com/nushell/nushell/pull/5891), and [Remove quotes from external args](https://github.com/nushell/nushell/pull/5846), and [Allow type comparison](https://github.com/nushell/nushell/pull/5844), and [Exclude ./... from expansion](https://github.com/nushell/nushell/pull/5839), and [Db commands without DB](https://github.com/nushell/nushell/pull/5838), and [Standardise to commands](https://github.com/nushell/nushell/pull/5800)
- rgwood created [Make sort logic available outside sort-by](https://github.com/nushell/nushell/pull/5893), and [Fix parser panic](https://github.com/nushell/nushell/pull/5820)
- skelly37 created [root/admin prompt is red now](https://github.com/nushell/nushell/pull/5836)
- wolimst created [Add Windows Terminal profile and icon in Windows control panel](https://github.com/nushell/nushell/pull/5812)
- kubouch created [Add test requirements to PR template](https://github.com/nushell/nushell/pull/5809)

## Extension

- schuelermine created [Fix typo in Snippet](https://github.com/nushell/vscode-nushell-lang/pull/55)

## Documentation

- petrisch created [DE translation for pipelines and scripts](https://github.com/nushell/nushell.github.io/pull/526), and [DE translation for working with lists and tables](https://github.com/nushell/nushell.github.io/pull/521), and [DE translation for loading data and working with strings](https://github.com/nushell/nushell.github.io/pull/512)
- merelymyself created [Changes misleading example](https://github.com/nushell/nushell.github.io/pull/525), and [Links `types_of_data` page to `describe` command](https://github.com/nushell/nushell.github.io/pull/522)
- relby created [Fix outdated `$false` value](https://github.com/nushell/nushell.github.io/pull/524)
- toastal created [Syntax highlighting as `console`](https://github.com/nushell/nushell.github.io/pull/523)
- hustcer created [Translate overlays.md to Chinese](https://github.com/nushell/nushell.github.io/pull/520), and [Fix broken images in README.md](https://github.com/nushell/nushell.github.io/pull/518), and [fix broken table rendering for operators](https://github.com/nushell/nushell.github.io/pull/517), and [Update zh_CN translation of dataframes and working_with_strings](https://github.com/nushell/nushell.github.io/pull/516), and [Update doc template for commands](https://github.com/nushell/nushell.github.io/pull/515), and [Update zh_CN translation for nu books](https://github.com/nushell/nushell.github.io/pull/514), and [feat: update some zh_CN translations of nu book](https://github.com/nushell/nushell.github.io/pull/513), and [Remove old_book related stuffs](https://github.com/nushell/nushell.github.io/pull/508), and [Fix command overlapping for `make_docs.nu` and Refresh commands for v0.64](https://github.com/nushell/nushell.github.io/pull/505)
- elferherrera created [Standard command name](https://github.com/nushell/nushell.github.io/pull/511)
- rgwood created [Remove MS CRT info now that we're statically linking it](https://github.com/nushell/nushell.github.io/pull/506)

## Nu Scripts

- fdncred created [update get_weather to use the new error make](https://github.com/nushell/nu_scripts/pull/261), and [add stargazer script to monitor nushell stars](https://github.com/nushell/nu_scripts/pull/260), and [add turtle benchmark and reorganize](https://github.com/nushell/nu_scripts/pull/259)
- Yethal created [Added delete-merged-branches.nu](https://github.com/nushell/nu_scripts/pull/255)
- skelly37 created [maths refactor](https://github.com/nushell/nu_scripts/pull/254), and [up.nu fixed](https://github.com/nushell/nu_scripts/pull/252)

## Reedline

- sholderbach created [Prepare the 0.8.0 release](https://github.com/nushell/reedline/pull/448)
- nibon7 created [Avoid subtraction overflow when using usize.](https://github.com/nushell/reedline/pull/446)
- WindSoilder created [introduce LastCommand variant for parse bang result](https://github.com/nushell/reedline/pull/445), and [fix double bang](https://github.com/nushell/reedline/pull/444)
- fdncred created [add impl Display to HistoryItemId and HistorySessionId](https://github.com/nushell/reedline/pull/443)
- drbrain created [Add vi r (replace)](https://github.com/nushell/reedline/pull/442), and [Add vi WORD motions B, E, W](https://github.com/nushell/reedline/pull/441)
