---
title: Nushell 0.67
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.67 of Nu. This is release includes a new variable naming convention, improvements to file modules and file sourcing, and more.
---

# Nushell 0.67

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your commandline. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful commandline pipelines.

Today, we're releasing version 0.67 of Nu. This is release includes a new variable naming convention, improvements to module imports and file sourcing, and more.

<!-- more -->

# Where to get it

Nu 0.67 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.67.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

If you want all the built-in goodies, you can install `cargo install nu --features=extra`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release

## We have a new welcome banner ([fdncred](https://github.com/nushell/nushell/pull/6163))

![New Nushell banner](../assets/images/0_67_header.png)

You can disable the banner using the `config nu` command to modify the config.nu file, just set `show_banner` to false:

```
let-env config {
    show_banner: false
    ...
}
```

## New variable naming convention ([jt](https://github.com/nushell/nushell/pull/6125))

**WARNING! Breaking change!**

In this release, we cleaned up some of the syntax parsing.
The major implication of it is that variable names can no longer contain `-` characters in it.
Make sure to rename your variables from `kebab-case` to `snake_case`.
This is true also for variables created from command flags.
For example, a `--foo-bar` flag in a command signature will be referenced by a `$foo_bar` variable.

## Relative paths in scripts are file-relative ([kubouch](https://github.com/nushell/nushell/pull/6150))

When you use `source`, `use`, or `overlay add` with a relative path in a script or a module file, the path is assumed to be relative to the file, not the current working directory.

Example:

```
# script.nu

use foo.nu *  # foo.nu is assumed to be relative to script.nu
```

## Writing SQLite files ([fdncred](https://github.com/nushell/nushell/pull/6266))

We added a fun way to create SQLite databases:

```
# create a database with a single table named `main`
ls | into sqlite my_ls.db

# same, but name the table `foo`
ls | into sqlite my_ls.db -t foo
```

Previously Nushell was limited to reading SQLite database files. Now we allow you to take tables or lists and create database files like `ls | into sqlite my_ls.db`. Currently this functionality works with regular table output from commands, table literals like `[[col1 col2]; [a b] [c d]]` and lists like `[one 10mib 20sec 2 2.5]`.

## Shell integration ([fdncred and Tyriar](https://github.com/nushell/nushell/pull/6087))

@fdncred worked with @Tyriar from the Visual Studio Code team on shell integration. Now Nushell will display round blue/red/gray decorations indicating the start of commands in the [VS Code terminal](https://code.visualstudio.com/docs/terminal/shell-integration):

![VS Code decorations](../assets/images/0_67_vs_code.png)

## Error Messages ([rgwood](https://github.com/nushell/nushell/pull/6256))

![new command not found error message](../assets/images/0_67_error_message.png)

The error message when an external command is not found has been improved. Nu now displays fancy [`miette`](https://github.com/zkat/miette) errors on all platforms including Windows, and it offers helpful suggestions for typos and mistaken command names.

## Windows `cmd.exe` changes ([rgwood](https://github.com/nushell/nushell/pulls?q=is%3Apr+is%3Aclosed+author%3Argwood+cmd))

Potentially breaking change: Nu no longer "shells out" to `cmd.exe` for any command that can't be found - only [a few known `cmd.exe` internal commands](https://github.com/rgwood/nushell/blob/00bace9e82d3f3e3e337c510ce6cef0818ade7aa/crates/nu-command/src/system/run_external.rs#L134). This change improves error handling and error messages, but let us know if it causes you any trouble.

## Bits and Bytes (hustcer and WindSoilder)

Nushell now has a full array of `bits` and `bytes` commands for working with binary data. @hustcer and @WindSoilder implemented the following:

- [bits ror and bits rol](https://github.com/nushell/nushell/pull/6224)
- [bits shl and bits shr](https://github.com/nushell/nushell/pull/6202)
- [bits or and bits xor](https://github.com/nushell/nushell/pull/6190)
- [bits root command and bits and](https://github.com/nushell/nushell/pull/6188)
- [bits not](https://github.com/nushell/nushell/pull/6143)

## Hiding Environment Variables ([kubouch](https://github.com/nushell/nushell/pull/6313))

A new `hide-env` command is added that can hide environment variables in the current scope.
`hide` still retains this functionality, but in the future, we expect `hide` to be able to hide only parser definitions (commands and aliases).
It is therefore recommended to change your `hide` calls to `hide-env` when dealing with environment variables.

Unlike `hide`, `hide-env` has a slightly different signature: It accepts multiple arguments and the arguments can be constructed dynamically:

```
> load-env {
    ENV_FOO: 'foo'
    ENV_BAR: 'bar'
}

> let prefix = 'ENV_'

> hide-env ($prefix + 'FOO') ($prefix + 'BAR')
```

## Prefixed Overlays ([kubouch](https://github.com/nushell/nushell/pull/6301))

The `overlay add spam` command would take all commands and aliases from the module and put them directly into the current namespace.
Sometimes, however, you might want them behind a prefix.
That's what `--prefix` is for.
Here is an example:

```
> module spam {
    export def foo [] { "foo" }
}

> overlay add --prefix spam

> spam foo
foo
```

## Customize Added Overlay Name ([kubouch](https://github.com/nushell/nushell/pull/6314))

You can now change the name of the added overlay using the new `as` keyword:

```
> module spam { export def foo [] { "foo" } }

> overlay add spam as eggs

> overlay list | last
eggs

> foo
foo

> overlay remove eggs
```

This can be useful if you have a generic script name, such as virtualenv's `activate.nu` but you want some more descriptive name for your overlay.

It is also compatible with the `--prefix` flag introduced above.

# Next Steps

Time for a new engine!

We've been looking through the fixes we'd need for some of the issues we're seeing and decided Nushell's core needs a thorough refactor. On [this Notion page](https://kubouch.notion.site/4db276462ba24704919edb4cc4b86be7?v=10506505557f4f7b9a65155128c04250) we started gathering ideas and design notes about features that we think should make it to the update. You can click the cards and they should expand into more detailed notes.

Many (most?) ideas are not polished yet and we need to work on the full design before we start the implementation. Therefore, we would like you to invite you to participate in the discussion. If you have questions, comments and ideas, please channel them to our `#design-discussion` channel on [our Discord](https://discord.com/invite/NtAbbGn). We especially welcome thorough design writeups. You can even "adopt" a topic and specialize in it, if you wish. And of course, later, we'll need help implementing everything.

By the end of this, we'll be heading towards 0.80 which should have all, or most of, the features we want for 1.0 and the work from 0.80 to 1.0 is expected to be mostly polish, bugfixes, IDE integrations, stabilizing the language, etc.

Oh, and if you're scared this will turn into another engine-q, this time our goal is to try to make the updates incrementally instead of building a new Nushell on the side and then replacing everything.

# Full changelog

## Nushell

- jt created [bump to 0.67](https://github.com/nushell/nushell/pull/6336), and [Fix intermittent test crash](https://github.com/nushell/nushell/pull/6268), and [bump dev version ahead of language changes](https://github.com/nushell/nushell/pull/6267), and [Move `ls` back to last-known-good state](https://github.com/nushell/nushell/pull/6175), and [Revert cp and mv back to last-known-good state](https://github.com/nushell/nushell/pull/6169)
- skelly37 created [Bug issue template](https://github.com/nushell/nushell/pull/6329)
- sholderbach created [Update to reedline 0.10.0](https://github.com/nushell/nushell/pull/6327), and [Update reedline to improved undo-system](https://github.com/nushell/nushell/pull/6326), and [Clippy fix for Rust 1.63](https://github.com/nushell/nushell/pull/6299), and [Reduce dev-deps by narrowing `rstest` features](https://github.com/nushell/nushell/pull/6215), and [Make `open` test independent of locale](https://github.com/nushell/nushell/pull/6211), and [Patch `lscolors` to not blink](https://github.com/nushell/nushell/pull/6210), and [Update crossterm to version 0.24](https://github.com/nushell/nushell/pull/6172)
- elferherrera created [lazy dataframe reader](https://github.com/nushell/nushell/pull/6321), and [Polars upgrade 0.23](https://github.com/nushell/nushell/pull/6303), and [sqlite query without collect](https://github.com/nushell/nushell/pull/6217), and [use `from table` to remove into-db command](https://github.com/nushell/nushell/pull/6205), and [maintain quotes for arguments](https://github.com/nushell/nushell/pull/6161)
- amtep created [Add repository info to all workspace crates](https://github.com/nushell/nushell/pull/6320)
- rgwood created [Bump chrono dependency to fix panic](https://github.com/nushell/nushell/pull/6317), and [run_external: only suggest alternatives when file not found](https://github.com/nushell/nushell/pull/6311), and [Clarify external command error](https://github.com/nushell/nushell/pull/6308), and [Fix unused import warning on Linux+Mac](https://github.com/nushell/nushell/pull/6281), and [Temporary: ignore Windows tests that fail on a local machine](https://github.com/nushell/nushell/pull/6279), and [Support running batch files without typing their extension](https://github.com/nushell/nushell/pull/6278), and [Clean up deprecated commands](https://github.com/nushell/nushell/pull/6260), and [Suggest alternative when command not found](https://github.com/nushell/nushell/pull/6256), and [Windows: only shell out to cmd for specific commands](https://github.com/nushell/nushell/pull/6253), and [Faster SQLite reads](https://github.com/nushell/nushell/pull/6204), and [Change `query` command to `query db`](https://github.com/nushell/nushell/pull/6200), and [Add $OLDPWD example for cd](https://github.com/nushell/nushell/pull/6194)
- kubouch created [Add 'as' keyword to 'overlay add'](https://github.com/nushell/nushell/pull/6314), and [Add `hide-env` to hide environment variables](https://github.com/nushell/nushell/pull/6313), and [Fix environment merging in hooks](https://github.com/nushell/nushell/pull/6309), and [Allow overlays to import prefixed definitions](https://github.com/nushell/nushell/pull/6301), and [Fix file lookup in parser keywords; Refactor nu_repl](https://github.com/nushell/nushell/pull/6185), and [Quickly patch wrong 'export' command name](https://github.com/nushell/nushell/pull/6168), and [Allow modules to `use` other modules](https://github.com/nushell/nushell/pull/6162)
- andrasio created [cmd(df/first): returns the first row by default.](https://github.com/nushell/nushell/pull/6312)
- WindSoilder created [make `date format` supports locale](https://github.com/nushell/nushell/pull/6306), and [not resolve symlink](https://github.com/nushell/nushell/pull/6304), and [when spawned process during register plugin, pass env to child process](https://github.com/nushell/nushell/pull/6261), and [add -n for path expand, so it doesn't follow symlink](https://github.com/nushell/nushell/pull/6255), and [fix python plugin example](https://github.com/nushell/nushell/pull/6242), and [In unix like system, set foreground process while running external command](https://github.com/nushell/nushell/pull/6206), and [Make default env works better with bash style PATH](https://github.com/nushell/nushell/pull/6176), and [Add bits not command](https://github.com/nushell/nushell/pull/6143)
- fdncred created [make ci use rust-toolchain.toml](https://github.com/nushell/nushell/pull/6305), and [add rust toolchain file to pin rust version](https://github.com/nushell/nushell/pull/6298), and [update build scripts](https://github.com/nushell/nushell/pull/6296), and [Revert "Allow using the system's copy of zstd for Polars"](https://github.com/nushell/nushell/pull/6292), and [update a few nushell dependencies](https://github.com/nushell/nushell/pull/6291), and [remove sharkdp's lscolors repo again](https://github.com/nushell/nushell/pull/6290), and [add search terms to ignore command](https://github.com/nushell/nushell/pull/6288), and [bump lscolors to v12.0](https://github.com/nushell/nushell/pull/6272), and [escape single quotes and remove ansi escape sequences](https://github.com/nushell/nushell/pull/6271), and [new command `into sqlite` allows you to take lists and create a sqlite database](https://github.com/nushell/nushell/pull/6266), and [add more verbose error messages to mv](https://github.com/nushell/nushell/pull/6259), and [point to the latest main branch for lscolors](https://github.com/nushell/nushell/pull/6230), and [remove the nana filename string, add some exclusions to gitignore](https://github.com/nushell/nushell/pull/6228), and [replace the regex crate with the fancy-regex crate](https://github.com/nushell/nushell/pull/6227), and [allow uppercase chars to be captured during suppressed input](https://github.com/nushell/nushell/pull/6199), and [add a new welcome banner to nushell](https://github.com/nushell/nushell/pull/6163), and [move application reset mode ansi sequence after cmdline execute](https://github.com/nushell/nushell/pull/6153)
- nibon7 created [Add custom log target to debugging tips](https://github.com/nushell/nushell/pull/6293), and [Fix panic when building without git](https://github.com/nushell/nushell/pull/6289), and [Fix color settings for logger](https://github.com/nushell/nushell/pull/6285), and [Return error when moving a source directory to a target directory whi…](https://github.com/nushell/nushell/pull/6284), and [Replace pretty_env_logger with simplelog](https://github.com/nushell/nushell/pull/6274), and [Refactor shell listing related code](https://github.com/nushell/nushell/pull/6262), and [Refactor shell switching related code](https://github.com/nushell/nushell/pull/6258), and [Make `g -` switch to the last used shell ](https://github.com/nushell/nushell/pull/6249), and [export `get_shells` and `get_current_shell`](https://github.com/nushell/nushell/pull/6236), and [Fix color parsing](https://github.com/nushell/nushell/pull/6234), and [Return error early if seconds part of timestamp is invalid](https://github.com/nushell/nushell/pull/6193), and [Fix touch panics when using invalid timestamp](https://github.com/nushell/nushell/pull/6181), and [Fix path_contains_hidden_folder](https://github.com/nushell/nushell/pull/6173), and [Prevent mv panic again](https://github.com/nushell/nushell/pull/6171), and [Prevent mv panic](https://github.com/nushell/nushell/pull/6158)
- merelymyself created [fix examples and let `into decimal` convert bools too](https://github.com/nushell/nushell/pull/6246), and [make `cd`, `cp`, `ls`, `mv`, `open` and `rm` automatically strip ansi codes](https://github.com/nushell/nushell/pull/6220), and [allow `-h` flags for `export` subcommands](https://github.com/nushell/nushell/pull/6189), and [adds a `config reset` command](https://github.com/nushell/nushell/pull/6149)
- Kangaxx-0 created [Fix issue 6223](https://github.com/nushell/nushell/pull/6241), and [Tweak how nu identifies custom command](https://github.com/nushell/nushell/pull/6187)
- hustcer created [upgrade chrono to v0.4.20](https://github.com/nushell/nushell/pull/6235), and [Some code refactor for shells related commands](https://github.com/nushell/nushell/pull/6226), and [add `bits ror` and `bits rol` commands](https://github.com/nushell/nushell/pull/6224), and [Add `bits shl` and `bits shr` command](https://github.com/nushell/nushell/pull/6202), and [Add `bits or` and `bits xor` command](https://github.com/nushell/nushell/pull/6190), and [Add bits root command and `bits and` command](https://github.com/nushell/nushell/pull/6188), and [bump to 0.66.3 dev version](https://github.com/nushell/nushell/pull/6183)
- winterqt created [Allow using the system's copy of zstd for Polars](https://github.com/nushell/nushell/pull/6232)
- x3rAx created [Add decimals to int when using `into string --decimals`](https://github.com/nushell/nushell/pull/6085)

## Extension

- fdncred created [one last tweak before release](https://github.com/nushell/vscode-nushell-lang/pull/58), and [prepare for new release](https://github.com/nushell/vscode-nushell-lang/pull/57), and [update gitignore](https://github.com/nushell/vscode-nushell-lang/pull/56)
- Yethal created [Updated patterns and added generation script](https://github.com/nushell/vscode-nushell-lang/pull/54)

## Documentation

- amtoine created [FIX: there is a minor typo in the modules page](https://github.com/nushell/nushell.github.io/pull/562), and [FIX: update the links to the default config files](https://github.com/nushell/nushell.github.io/pull/552)
- johnae created [Update direnv.md](https://github.com/nushell/nushell.github.io/pull/561), and [Update config.js/cookbook with direnv example](https://github.com/nushell/nushell.github.io/pull/555), and [Create direnv.md](https://github.com/nushell/nushell.github.io/pull/554)
- azzamsa created [docs: fix grammar error](https://github.com/nushell/nushell.github.io/pull/560), and [docs: contributing workflow is outdated](https://github.com/nushell/nushell.github.io/pull/559), and [fix: all clickable items should have the same color](https://github.com/nushell/nushell.github.io/pull/558)
- kubouch created [Document hide-env and overlay additions](https://github.com/nushell/nushell.github.io/pull/557)
- willemneal created [chore: small edit](https://github.com/nushell/nushell.github.io/pull/553)
- jeremiahpslewis created [Update links to config template](https://github.com/nushell/nushell.github.io/pull/550)
- rgwood created [Document SQLite data loading](https://github.com/nushell/nushell.github.io/pull/549), and [Explain how to launch Nu after installing](https://github.com/nushell/nushell.github.io/pull/546)
- petrisch created [DE Translation for Coloring and Theming ](https://github.com/nushell/nushell.github.io/pull/548)
- fdncred created [update gitignore](https://github.com/nushell/nushell.github.io/pull/547)

## Nu_Scripts

- johnae created [Update direnv example to run in pre_prompt rather than env_change](https://github.com/nushell/nu_scripts/pull/276), and [Add direnv config example.](https://github.com/nushell/nu_scripts/pull/272)
- fantasyzhjk created [add rbenv script](https://github.com/nushell/nu_scripts/pull/274)
- fdncred created [update some scripts from dash to underscore, add 20k_club script](https://github.com/nushell/nu_scripts/pull/271), and [update gitignore](https://github.com/nushell/nu_scripts/pull/270), and [winget: switch kebab case parameters to snake case](https://github.com/nushell/nu_scripts/pull/269)
- WindSoilder created [Migrate some scripts to fit new variable and arguments naming style](https://github.com/nushell/nu_scripts/pull/268)
- skelly37 created [Unspanned error](https://github.com/nushell/nu_scripts/pull/267)

## reedline

- sholderbach created [Prepare 0.10.0 release](https://github.com/nushell/reedline/pull/463), and [Clippy fix for tests](https://github.com/nushell/reedline/pull/462), and [Reduce dev-deps by narrowing `rstest` features](https://github.com/nushell/reedline/pull/458), and [Export the crossterm key types](https://github.com/nushell/reedline/pull/457), and [Update crossterm to 0.24](https://github.com/nushell/reedline/pull/447)
- morzel85 created [Ctrl+h edit binding moved from emacs to common](https://github.com/nushell/reedline/pull/461)
- bnprks created [Improve undo functionality](https://github.com/nushell/reedline/pull/460), and [Vi mode add support for d0, d^, c0, and c^](https://github.com/nushell/reedline/pull/459)
- fdncred created [update gitignore](https://github.com/nushell/reedline/pull/455)
