---
title: Nushell 0.68
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.68 of Nu. This is release a rework of modules, a new source-env command, overlay changes, and more.
---

# Nushell 0.68

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your commandline. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful commandline pipelines.

Today, we're releasing version 0.68 of Nu. This is release a rework of modules, a new source-env command, overlay changes, and more.

<!-- more -->

# Where to get it

Nu 0.68 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.68.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

If you want all the built-in goodies, you can install `cargo install nu --features=extra`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release

## (Major changes!) Rework of modules and environment

_Some of the changes here have far-reaching consequences and it might take a while to get the book up to speed._

This release includes a bundle of changes to environment handling and modules.
For now, we kept also the old functionality, but in the 0.69, it will be removed.
It is therefore recommended to port your scripts and modules to the new style to avoid breakages in the next release.
You can read a more complete write-up on the motivation and overall design in [this document](https://hackmd.io/@nucore/r1zilyw6q).

### `source` becomes `source-env` ([JT, kubouch](https://github.com/nushell/nushell/pull/6277))

_**Note: Since the release we found out that `source-env` with a dynamic path is not viable and had to make it require a constant string or path, just like `source`. The command still works as described below but as of 0.68.1, `source-env` requires a static path as an argument. This is not where our design was supposed to land and we'll be searching for alternatives. We might also postpone the deprecation of the existing module commands beyond 0.69. Thanks for understanding.**_

One of the most common pitfalls of Nushell was trying to `source` a dynamic path, such as `source ($env.PWD | path join foo.nu)`.
Since Nushell is a "compiled" language where commands and aliases are analyzed while parsing ("compiling") the code, sourcing dynamic paths is not possible for the same reason you cannot dynamically set `#include` file names in C or `use` modules in Rust.
You can read a bit more about this in [our Thinking in Nu book chapter](https://www.nushell.sh/book/thinking_in_nu.html#think-of-nushell-as-a-compiled-language).

To address this pitfall, we decided to change `source` to `source-env` which can be used to bring in the environment, but not custom commands, aliases and variables anymore.
~~A benefit of doing so is that it is now **possible to pass dynamic paths**: `source-env ($env.PWD | path join foo.nu)` would bring in the environment from the `foo.nu` file.~~

_How do you bring in commands and aliases without `source`?_ You need to use a module and the `use` keyword. See our book chapter [about modules](https://www.nushell.sh/book/modules.html), it's quite simple. Alternatively, you can use [overlays](https://www.nushell.sh/book/overlays.html).

_How do you bring in variables without `source`?_ This is not possible anymore. A workaround is to define a command in your module that will return the value you want.

`source` still continues to work in this release but will be removed in 0.69. In 0.69, we will also change all config files to be modules, not plain scripts.

### Module environment changes ([kubouch](https://github.com/nushell/nushell/pull/6355), [kubouch](https://github.com/nushell/nushell/pull/6382))

The way to define environment variables from modules used to be

```
> module spam {
    export env FOO { 'bar' }
}

> use spam
```

This example shows one problem: it is easy to end up with namespaced environment variables, which in this case would be `$env.'spam FOO'`.
Another problem with the current design is that `use` is a parser keyword (like the removed `source`) but contains both parser ("compiled") and runtime (evaluated) functionality.
Since 0.67, it is possible to [use modules within other modules](https://github.com/nushell/nushell/pull/6162) but because environment is 100% handled in runtime, and `use` never evaluates the module itself, it was impossible to bring in environment variables from other modules inside a module.

Long story short, `use` (and `hide`) now handle **only custom commands and aliases**, not environment variables anymore.
If you want to bring both environment and commands/aliases, you need to use the `source-env` and `use` commands separately (or use overlays).

Also, we simplified defining the environment in modules. Instead of defining environment variables with `export env` individually, there is a single `export-env { }` block for the whole module (see the example in the next section).

If you call `source-env` on that module, the `export-env` command will get evaluated and its environment kept in the current scope.

```
# spam.nu

export-env {
    let-env FOO = 'foo'
    let-env BAR = 'bar'
}
```

```
> source-env spam.nu

> $env.FOO
foo

> $env.BAR
bar
```

This release makes `export env` deprecated and it will be removed in 0.69.

### Syntax unification ([kubouch](https://github.com/nushell/nushell/pull/6357))

Previously, modules had some reserved syntax that was not valid in scripts: the `export` keywords.
In this release, we allowed `export` keywords to be used in scripts (they do nothing: `export def` acts as `def` etc.) and thus **script syntax is a superset of module syntax**.

Modules can now be evaluated. This is the reason the above example with `source-env` works: Thanks to the unified syntax, `source-env` will evaluate the module which evaluates the `export-env` command inside the module.

Another nice thing about the unified syntax is that commands like `nu-highlight` now do not break or do not need to rely on heuristics if they are asked to parse a module code. Any module code is a valid script code.

### Overlay changes ([kubouch](https://github.com/nushell/nushell/pull/6425), [WindSoilder](https://github.com/nushell/nushell/pull/6375))

`overlay add` and `overlay remove` are now renamed to `overlay use` and `overlay hide` (see the breaking changes later).

The functionality of these commands remains largely the same with one change being that `overlay use` will now evaluate the `export-env { }` block.
Consider this module:

```
# spam.nu

export-env {
    load-env {
        FOO: 'foo'
        BAR: 'bar'
    }
}

export def foo [] { 'foo' }
export alias bar = 'bar'
```

instead of:

```
> source-env spam.nu

> use spam.nu *
```

you can do just:

```
> overlay use spam.nu
```

You can think of `overlay use` as calling `source-env` and `use` in one command and putting the result into a new overlay.

### Summary

Here is a table that summarizes the changes:

| command      | previous release (0.67)                             | this release (0.68)                                                    | next release (0.69)               |
| ------------ | --------------------------------------------------- | ---------------------------------------------------------------------- | --------------------------------- |
| `source`     | imports everything into the current scope           | same (deprecated)                                                      | removed                           |
| `source-env` | N/A                                                 | imports environment variables                                          | same                              |
| `use`        | imports environment variables, commands and aliases | same                                                                   | imports only commands and aliases |
| `hide`       | hides environment variables, commands and aliases   | same                                                                   | hides only commands and aliases   |
| `hide-env`   | hides environment variables                         | same                                                                   | same                              |
| `export env` | defines a single environment variable in a module   | same                                                                   | removed                           |
| `export-env` | N/A                                                 | (in a module) defines the environment for the whole module             | same                              |
| `export-env` | N/A                                                 | (in a script) when evaluated, preserves the environment from the block | same                              |
| `export ...` | only allowed in a module                            | allowed in a script as well                                            | same                              |
| `config.nu`  | plain script                                        | plain script                                                           | module                            |
| `env.nu`     | plain script                                        | plain script                                                           | module                            |
| `login.nu`   | plain script                                        | plain script                                                           | module                            |

## Allow parentheses around command signatures ([JT](https://github.com/nushell/nushell/pull/6444))

To bring more familiarity with other languages, we added the option to define command signatures with parentheses `()` instead of only braces `[]`:

```
def foo (x: int) { $x + 100 }
```

The square braces `[]` continue to work as well.
This change is intended to test it with a larger audience to decide which one we prefer the most.

## We added a new command `str distance` which implements the Levenshtein algorithm [fdncred](https://github.com/nushell/nushell/pull/6383)

This example shows that the `edit distance` is one edit step difference using the Levenshtein algorithm.

```sh
> 'nushell' | str distance 'nutshell'
╭──────────┬───╮
│ distance │ 1 │
╰──────────┴───╯
```

We'd eventually like to add more similarity comparison functionality to nushell.

## We added string duration conversion to named durations [fdncred](https://github.com/nushell/nushell/pull/6406)

The new parameter on `into duration` `--convert` allows you to convert from string durations into named durations.

```sh
> '7min' | into duration --convert sec
420 sec
```

## External Completions (experimental) ([herlon214, rsteube](https://github.com/nushell/nushell/pull/6295))

In this release, we're trying out integrating Nushell with external completers, instead of relying solely on Nushell ones. It is possible to set the `external_completer` field in a config to be a block which will be evaluated if no Nushell completions were found. You can configure the block to run an external completer, such as [carapace](https://github.com/rsteube/carapace).

This example should enable carapace external completions:

```
# config.nu
let carapace_completer = {|spans|
    carapace $spans.0 nushell $spans | from json
}

# The default config record. This is where much of your global configuration is setup.
let-env config = {
    # ... your config
    external_completer: $carapace_completer
}
```

Note that this functionality is not perfectly polished yet and in some cases the external completer is not triggered correctly (see [this issue](https://github.com/nushell/nushell/issues/6378)).

It is also possible to extend the parameters passed to the completer block that are required for other tools than carapace, such as cursor position etc.
In theory, this feature could allow you to utilize any existing completions library from any shell, such as bash, as long as you can somehow get a list of completions from them.

# Breaking changes

## Renaming of `all?` to `all`, `any?` to `any`, and `empty?` to `is-empty` ([adamijak](https://github.com/nushell/nushell/pull/6464))

The `?` suffix on the three commands `all?`, `any?`, `empty?` did not indicate a specific meaning across other commands.
Other commands returning a boolean value, like `str contains` for example, don't carry the suffix.
To remove a potential source of confusion and to free up the `?` for potential use in a more meaningful semantic context, we decided to remove the suffix and rename `empty?` to `is-empty` to clarify its role.

Please update your scripts accordingly:

| old name | new name   |
| -------- | ---------- |
| `all?`   | `all`      |
| `any?`   | `any`      |
| `empty?` | `is-empty` |

## Renaming `overlay` commands ([WindSoilder](https://github.com/nushell/nushell/pull/6375))

| old name         | new name       |
| ---------------- | -------------- |
| `overlay add`    | `overlay use`  |
| `overlay remove` | `overlay hide` |

The main reason is that the `overlay remove` does not _really_ remove the overlay.
It deactivates it and it can be resumed again from where you left off.
Therefore, we felt like `hide` is a better word to match this functionality and aligns with our existing `use` and `hide` keywords.

## `path split` behaviour for Windows paths ([merelymyself](https://github.com/nushell/nushell/pull/6485))

`path split` no longer returns drive letters and the root directory as separate elements for absolute Windows paths.

Previously, `` `C:\temp` | path split`` returned `C:`, `\`, and `temp`. Now it returns `C:\` and `temp`.

# Next Steps

We've been progressing with our design towards 0.80 as outlined in [this Notion page](https://kubouch.notion.site/4db276462ba24704919edb4cc4b86be7?v=10506505557f4f7b9a65155128c04250).

Some time was spent trying out possible new syntax directions but we were not confident to release them yet. In the next release we'll see a removal of features deprecated in this release and we'll continue to push ahead for the 0.80.

# Full changelog

## Nushell

- jt created [bump to 0.68](https://github.com/nushell/nushell/pull/6501), and [Reverted "Make `$` on variable names optional" (just in case)](https://github.com/nushell/nushell/pull/6446), and [Allow parens around signatures](https://github.com/nushell/nushell/pull/6444), and [Make `$` on variable names optional](https://github.com/nushell/nushell/pull/6434), and [Move from `source` to `source-env`](https://github.com/nushell/nushell/pull/6277)
- sholderbach created [Pin reedline to 0.11.0 release](https://github.com/nushell/nushell/pull/6497), and [Terminate REPL if not connected to tty input](https://github.com/nushell/nushell/pull/6480), and [Fix search terms for `str distance`](https://github.com/nushell/nushell/pull/6398), and [[Experiment] Reenable CI build cache for tests](https://github.com/nushell/nushell/pull/6390), and [Test command names and search terms for redundancy](https://github.com/nushell/nushell/pull/6380)
- merelymyself created [let path split keeps 'C:\' together](https://github.com/nushell/nushell/pull/6485), and [Allow for rejecting nested record cells](https://github.com/nushell/nushell/pull/6463), and [add tests, deal with pipes, newlines, tabs for `to nuon`](https://github.com/nushell/nushell/pull/6391), and [preserve space by letting `to nuon` only add quotes when necessary](https://github.com/nushell/nushell/pull/6379), and [let `to nuon` convert column names with spaces](https://github.com/nushell/nushell/pull/6376), and [default to file completion after first command, add `command` option for completions](https://github.com/nushell/nushell/pull/6257)
- unrelentingtech created [Avoid update_last_command_context "No command run" error](https://github.com/nushell/nushell/pull/6483), and [Fix build on \*BSD, illumos, etc.](https://github.com/nushell/nushell/pull/6456)
- WindSoilder created [Restrict plugin name starts with `nu_plugin_`](https://github.com/nushell/nushell/pull/6479), and [remove capnp relative file](https://github.com/nushell/nushell/pull/6472), and [shows wrong item when some commands runs to failed.](https://github.com/nushell/nushell/pull/6442), and [shows wrong item when each command runs to failed.](https://github.com/nushell/nushell/pull/6437), and [keep raw for variable inputted argument](https://github.com/nushell/nushell/pull/6426), and [remove capnp protocol for plugin...](https://github.com/nushell/nushell/pull/6421), and [Try to make argument with quotes for external command better](https://github.com/nushell/nushell/pull/6420), and [Plugin: Add benchmark for different encoding protocol](https://github.com/nushell/nushell/pull/6384), and [Rename overlay commands](https://github.com/nushell/nushell/pull/6375), and [Try again: in unix like system, set foreground process while running external command](https://github.com/nushell/nushell/pull/6273)
- kubouch created [Disable cyclical module imports](https://github.com/nushell/nushell/pull/6477), and [Fix overlays not preserving hidden env vars](https://github.com/nushell/nushell/pull/6475), and [Fix scoped `overlay use` not finding a module](https://github.com/nushell/nushell/pull/6474), and [Bring in module's environment when activating overlay](https://github.com/nushell/nushell/pull/6425), and [Allow "export-env" parsing in modules](https://github.com/nushell/nushell/pull/6382), and [Allow parsing modules as scripts](https://github.com/nushell/nushell/pull/6357), and [Add `export-env` command](https://github.com/nushell/nushell/pull/6355)
- adamijak created [Rename `all?`, `any?` and `empty?`](https://github.com/nushell/nushell/pull/6464)
- dependabot[bot] created [Bump lz4-sys from 1.9.3 to 1.9.4](https://github.com/nushell/nushell/pull/6462), and [Bump iana-time-zone from 0.1.44 to 0.1.47](https://github.com/nushell/nushell/pull/6448)
- obaudys created [Fix ps command CPU usage on Apple Silicon M1 macs. #4142](https://github.com/nushell/nushell/pull/6457)
- fdncred created [Revert "Add support for optional list stream output formatting"](https://github.com/nushell/nushell/pull/6454), and [add more color highlighting to help](https://github.com/nushell/nushell/pull/6449), and [add the ast command to peek at the internals of nushell](https://github.com/nushell/nushell/pull/6423), and [convert string duration to named duration](https://github.com/nushell/nushell/pull/6406), and [add a plugin registration script](https://github.com/nushell/nushell/pull/6395), and [add another split words example](https://github.com/nushell/nushell/pull/6394), and [add edit distance/levenshtein command](https://github.com/nushell/nushell/pull/6383), and [add MessagePack as a plugin protocol](https://github.com/nushell/nushell/pull/6370), and [fix the way lists are rendered in markdown](https://github.com/nushell/nushell/pull/6369), and [add a split words command](https://github.com/nushell/nushell/pull/6363), and [create clickable links in ls output if configured](https://github.com/nushell/nushell/pull/6333)
- rgwood created [Upgrade `which` dependency to fix case on Windows](https://github.com/nushell/nushell/pull/6453), and [Disable clickable links in SSH sessions](https://github.com/nushell/nushell/pull/6439), and [Always report errors in `cp`](https://github.com/nushell/nushell/pull/6404), and [Make `cp` errors more specific+accurate](https://github.com/nushell/nushell/pull/6396), and [Add pause and cls to cmd.exe exceptions](https://github.com/nushell/nushell/pull/6371)
- dscottboggs created [better error handling for nu_command::env::conig::utils::get_editor](https://github.com/nushell/nushell/pull/6430)
- nibon7 created [Make run_external parameter required](https://github.com/nushell/nushell/pull/6418), and [Fix the span of "invalid time zone"](https://github.com/nushell/nushell/pull/6411), and [register-plugin.nu: refactor register plugin](https://github.com/nushell/nushell/pull/6409), and [register-plugin.nu: remove `.exe` extension match to simplify code](https://github.com/nushell/nushell/pull/6400), and [Add test cases for $nu.config-path change](https://github.com/nushell/nushell/pull/6385), and [Get `$nu.config-path` and `$nu.env-path` from `EngineState`](https://github.com/nushell/nushell/pull/6366), and [Use string interpolation to construct log file path](https://github.com/nushell/nushell/pull/6365), and [Return error when `kill` didn't terminate successfully ](https://github.com/nushell/nushell/pull/6354)
- herlon214 created [nu-command/filters: drop column check positive value](https://github.com/nushell/nushell/pull/6412), and [nu-cli: merge completions tests into one file](https://github.com/nushell/nushell/pull/6389), and [feat: external completions for commands/flags](https://github.com/nushell/nushell/pull/6295)
- hustcer created [Update nu version for release workflow](https://github.com/nushell/nushell/pull/6361), and [Bump dev version](https://github.com/nushell/nushell/pull/6350)
- volucris1 created [Fix #6330](https://github.com/nushell/nushell/pull/6332)
- panicbit created [Add support for optional list stream output formatting](https://github.com/nushell/nushell/pull/6325)
- dbuch created [Fix slice indexing](https://github.com/nushell/nushell/pull/6322)
- CohenAriel created [Add --execute option](https://github.com/nushell/nushell/pull/6302)

## Documentation

- rgwood created [Add Homebrew PATH documentation](https://github.com/nushell/nushell.github.io/pull/592)
- sholderbach created [Update former question mark commands in docs](https://github.com/nushell/nushell.github.io/pull/590)
- chrjen created [Update types_of_data.md with missing values](https://github.com/nushell/nushell.github.io/pull/589)
- hustcer created [Upgrade vuepress and all related plugins to improve build performance](https://github.com/nushell/nushell.github.io/pull/588), and [Upgrade all vuepress plugins and fix doc search navigation by pressing `enter` key](https://github.com/nushell/nushell.github.io/pull/587), and [Upgrade all vuepress plugins and fix doc search navigation by pressing `enter` key](https://github.com/nushell/nushell.github.io/pull/586), and [Try to fix deploy of docs by downgrade some plugins](https://github.com/nushell/nushell.github.io/pull/585), and [lock vuepress and plugins version to fix ci](https://github.com/nushell/nushell.github.io/pull/582)
- fdncred created [update to ubuntu-latest](https://github.com/nushell/nushell.github.io/pull/584), and [change from deprecated version of ubuntu](https://github.com/nushell/nushell.github.io/pull/583)
- pedromfedricci created [Update accepted types for signatures](https://github.com/nushell/nushell.github.io/pull/580)
- Yethal created [Add wrap-around merge](https://github.com/nushell/nushell.github.io/pull/579)
- merelymyself created [Remove ambiguity about command quotes](https://github.com/nushell/nushell.github.io/pull/577)
- CAD97 created [Note status of calling CMD builtins from Nushell](https://github.com/nushell/nushell.github.io/pull/573), and [Note Windows caveat in Escaping to the System](https://github.com/nushell/nushell.github.io/pull/572), and [Mention coming_from_cmd in coming_to_nu](https://github.com/nushell/nushell.github.io/pull/571), and [Update coming_from_cmd.md for nu 0.77](https://github.com/nushell/nushell.github.io/pull/570), and [Create coming_from_cmd.md](https://github.com/nushell/nushell.github.io/pull/567)
- 1submarine created [correct escapes in coming_from_bash.md](https://github.com/nushell/nushell.github.io/pull/569), and [deduplicate `\*\*' in operators.md](https://github.com/nushell/nushell.github.io/pull/568)
- amtoine created [FIX: `overlay remove` flags](https://github.com/nushell/nushell.github.io/pull/565)

## Nu Scripts

- dandavison created [Async git prompt](https://github.com/nushell/nu_scripts/pull/288)
- sholderbach created [Update old question mark commands `any?`/`all?`/`empty?` to `any`/`all`/`is-empty`](https://github.com/nushell/nu_scripts/pull/287)
- skelly37 created [Added German diacritics](https://github.com/nushell/nu_scripts/pull/284)
- Yethal created [Add function to remove diacritics from string](https://github.com/nushell/nu_scripts/pull/283)
- fdncred created [remove engine-q references](https://github.com/nushell/nu_scripts/pull/282)
- e2dk4r created [custom completions: scoop: add some missing command completions](https://github.com/nushell/nu_scripts/pull/281), and [custom completions: scoop: add some missing command completions](https://github.com/nushell/nu_scripts/pull/280)
- mk00pl created [added webscrapping script for twitter](https://github.com/nushell/nu_scripts/pull/279)
- azzamsa created [fix: zoxide support Nushell out of the box](https://github.com/nushell/nu_scripts/pull/278)

## reedline

- sholderbach created [Prepare 0.11.0 release](https://github.com/nushell/reedline/pull/471)
- unrelentingtech created [Add Reedline::has_last_command_context to allow checking if update_last_command_context will fail](https://github.com/nushell/reedline/pull/470)
- nibon7 created [Fix panic when using sqlite as history backend](https://github.com/nushell/reedline/pull/469)
- morzel85 created [README.md outline cleanup](https://github.com/nushell/reedline/pull/466)
