---
title: Nushell 0.75
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.75 of Nu. This release extends our unicode support, renames some important HTTP-related commands, and improves our module system. It also contains a good amount of polish and refactoring behind the scenes.
---

# Nushell 0.75

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your command line. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful command line pipelines.

Today, we're releasing version 0.75 of Nu. This release extends our unicode support, renames some important HTTP-related commands, and improves our module system. It also contains a good amount of polish and refactoring behind the scenes.

<!-- more -->

# Where to get it

Nu 0.75 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.75.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

NOTE: The optional dataframe functionality is available by `cargo install nu --features=dataframe`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release / New features

## Changed Unicode escapes in strings ([bobhy](https://github.com/nushell/nushell/pull/7883))

::: warning

**Breaking Change**: You need to update escapes like `"\u0043"` to `"\u{0043}"`

:::

New format:

```bash
〉echo "AB\u{43}\u{044}"
ABCD
〉echo "Gabriel, blow your \u{1f3BA}"
Gabriel, blow your 🎺
```

Instead of:

```bash
〉echo "AB\u0043"
ABC
```

This format allows you to insert any Unicode code point into a string by specifying its value as 1 through 6 hex digits (with or without leading zeros, upper or lower case). The maximum value is `\u{10ffff}`, which is the largest Unicode code point defined.

We've simply dropped support for the old format since we're pre-1.0 and didn't want to carry forward redundant syntax. You will have to change any unicode escapes in your scripts to the new format.

_Why change?_ The old 4-digit syntax could not natively address recent extensions to Unicode standard, such as emoji, CJK extension and traditional scripts. There is a cumbersome workaround in the form of [surrogate pairs](https://unicodebook.readthedocs.io/unicode_encodings.html#surrogates), but this is not intuitive.

Why this change? The new format allows you to specify any Unicode code point with a single, predictable syntax. Rust and ECMAScript 6 support the same syntax. (Full disclosure: C++, Python and Java don't.)

## `-g` grapheme cluster flags for `str length`, `str substring`, `str index-of`, `split words` and `split chars` ([webbedspace](https://github.com/nushell/nushell/pull/7752))

As you know, `str length`, `str substring`, `str index-of` and `split words` measure the length of strings and substrings in UTF-8 bytes, which is often very unintuitive - all non-ASCII characters are of length 2 or more, and splitting a non-ASCII character can create garbage characters as a result. A much better alternative is to measure the length in _extended grapheme clusters_. In Unicode, a "grapheme cluster" tries to map as closely as possible to a single visible character. This means, among many other things:

- Non-ASCII characters, such as `ん`, are considered single units of length 1, no matter how many UTF-8 bytes they use.
- Combined characters, such as `e` and `◌́ ` being combined to produce `é`, are considered single units of length 1.
- Emojis, including combined emojis such as 🇯🇵, which is made of the 🇯 and 🇵 emojis plus a zero-width joiner, are considered single units of length 1. (This is a property of "extended" grapheme clusters.)
- `"\r\n"` is considered a single unit of length 1.

The new `--graphemes`/`-g` flag can be used with `str length`, `str substring`, `str index-of` and `split words` to enable these length/indexing measurements:

```
〉'🇯🇵ほげ ふが ぴよ'   | str substring 4..6 -g
ふが
〉'🇯🇵ほげ ふが ぴよ'   | str length -g
9
〉'🇯🇵ほげ ふが ぴよ'   | str index-of 'ふが' -g
4
```

In addition, the flag has been added to `split chars`. Notably, this command splits on Unicode code points rather than UTF-8 bytes, so it doesn't have the issue of turning non-ASCII characters into garbage characters. However, combining emoji and combining characters do not correspond to single code points, and are split by `split chars`. The `-g` flag keeps those characters intact:

```
〉'🇯🇵ほげ' | split chars -g | to nuon
[🇯🇵, ほ, げ]
```

These commands also have `--utf-8-bytes`/`-b` flags which enable the legacy behavior (and `split chars` has `--code-points`/`-c`). These currently _do not do anything_ and need not strictly be used, since UTF-8 byte lengths are still the default behaviour. However, if this default someday changes, then these flags will guarantee that the legacy behaviour is used.

::: tip

It is currently being debated whether or not grapheme clusters should be used as the default string length measurement in Nushell (making the `-g` flag the default behaviour for these commands), due to their intuitiveness, consistency across non-Latin scripts, and better correspondence to the length of strings displayed in the terminal (after stripping ANSI codes). Currently, the Nushell developers are uncertain what the long-term impact of such a change would be, whether existing scripts would be non-trivially harmed by it, or whether it would hinder interoperability with external programs. If you have any personal insight or opinion about this change, or about which behaviour you'd prefer not to require a flag, your input is desired!

:::

## New `enumerate` command ([JT](https://github.com/nushell/nushell/pull/7871))

A new `enumerate` command will enumerate the input, and add an index and item record for each item. The index is the number of the item in the input stream, and item is the original value of the item.

```
> ls | enumerate | get 14
╭───────┬────────────────────────────╮
│ index │ 14                         │
│       │ ╭──────────┬─────────────╮ │
│ item  │ │ name     │ crates      │ │
│       │ │ type     │ dir         │ │
│       │ │ size     │ 832 B       │ │
│       │ │ modified │ 2 weeks ago │ │
│       │ ╰──────────┴─────────────╯ │
╰───────┴────────────────────────────╯
```

Rather than relying on the `--numbered` flags of commands like `each`, with the `enumerate` command we take more modular and composable approach than hard-coding flags to our commands. (Note: The `--numbered` flags have not been removed yet.)

## Breaking changes to the web-related commands ([Kazuki-Ya](https://github.com/nushell/nushell/pull/7796), [VincenzoCarlino](https://github.com/nushell/nushell/pull/7702))

We decided to move some of the important command for interacting with HTTP under their own `http` subcommands for better discoverability.
The common `fetch` command is now `http get`.

| Old name | New name beginning with `0.75` |
| -------- | ------------------------------ |
| `fetch`  | `http get`                     |
| `post`   | `http post`                    |
| `to url` | `url build-query`              |

## `main` command exported from module defines top-level module command ([kubouch](https://github.com/nushell/nushell/pull/7764))

Defining and exporting a `main`command from a module allows creating a command with the same name as the module. Consider this example:

```
# command.nu
export def main [] { 'This is a command' }

export def subcommand [] { 'This is a subcommand' }
```

Then:

```
> use command.nu

> command
This is a command

> command subcommand
This is a subcommand
```

The same thing works `overlay use` as well. Note that the `main` command continues to work the same way as before when running a script:

```
> nu command.nu
This is a command
```

Combined with a [recent bugfix](https://github.com/nushell/nushell/pull/7830), this feature allows for nicer way of defining known externals and custom completions.

Before:

```
# cargo.nu

export extern cargo [--version, --color: string@cargo-color-complete]

export extern `cargo check` [--quiet]

def cargo-color-complete [] {
    [ auto, always, never ]
}
```

After:

```
# cargo.nu

export extern main [--version, --color: string@cargo-color-complete]

export extern check [--quiet]

def cargo-color-complete [] {
    [ auto, always, never ]
}
```

It is also a stepping stone towards being able to handle directories which in turn is a stepping stone towards having proper Nushell packages.

## Progress bar for `save` command ([Xoffio](https://github.com/nushell/nushell/pull/7661))

To watch the progress when saving large files you can now pass the `--progress` flag to `save`.
It gives information about the throughput and an interactive progress bar if available.

![Progress for saving a file](../assets/images/0_75_save_progress.png)

# Breaking changes

- Unicode escapes in strings now use and extended format `\u{X...}`, any scripts using the old syntax `\uXXXX` will have to be updated. See also [#7883](https://github.com/nushell/nushell/pull/7883).
- The `to url` command has been renamed and moved to `url build-query` as this better reflects is role as a nushell specific `url` command compared to a conversion. ([#7702](https://github.com/nushell/nushell/pull/7702))
- `fetch` has been renamed to `http get` ([#7796](https://github.com/nushell/nushell/pull/7796))
- `post` has been renamed to `http post` ([#7796](https://github.com/nushell/nushell/pull/7796))
- Quotes are trimmed when escaping to `cmd.exe` ([#7740](https://github.com/nushell/nushell/pull/7740))
- `parse -r` now uses zero-indexed rows and uncapitalized columns ([#7897](https://github.com/nushell/nushell/pull/7897))
- `last`, `skip`, `drop`, `take until`, `take while`, `skip until`, `skip while`, `where`, `reverse`, `shuffle`, `append`, `prepend` and `sort-by` raise error when given non-lists ([#7623](https://github.com/nushell/nushell/pull/7623))
- `to csv` and `to tsv` now throw error on unsupported inputs ([7850](https://github.com/nushell/nushell/pull/7850))

# Full changelog

## Nushell

- kubouch created [Remove deprecated `where -b` parameter](https://github.com/nushell/nushell/pull/7927), and [Fix panic when assigning value to $env](https://github.com/nushell/nushell/pull/7894), and [Fix wrong VarId of $in variable](https://github.com/nushell/nushell/pull/7893), and [Fix command name lookup for known externals](https://github.com/nushell/nushell/pull/7830), and [Allow main command to define top-level module command](https://github.com/nushell/nushell/pull/7764), and [Add const support for all overlay commands](https://github.com/nushell/nushell/pull/7720)
- fdncred created [update type check so that ++ with lists works better](https://github.com/nushell/nushell/pull/7926), and [with the release of rust 1.67, let's bump to 1.66.1](https://github.com/nushell/nushell/pull/7866), and [add decimal to SyntaxShape](https://github.com/nushell/nushell/pull/7852), and [add some startup performance metrics](https://github.com/nushell/nushell/pull/7851), and [print nushell startup time](https://github.com/nushell/nushell/pull/7831), and [fix signature display in help commands](https://github.com/nushell/nushell/pull/7802), and [update sqlparser dependency](https://github.com/nushell/nushell/pull/7772), and [update semver dep](https://github.com/nushell/nushell/pull/7771), and [Add cursor shape configuration for each edit mode](https://github.com/nushell/nushell/pull/7745), and [update base64 implementation to newer crate](https://github.com/nushell/nushell/pull/7739), and [update release-pkg comments for manual runs](https://github.com/nushell/nushell/pull/7726)
- sholderbach created [Pin `reedline` to new `0.15` for release](https://github.com/nushell/nushell/pull/7918), and [Apply more recent/nightly clippy lints](https://github.com/nushell/nushell/pull/7916), and [Bump `trash` to `3.0.1`](https://github.com/nushell/nushell/pull/7914), and [Use variable names directly in the format strings](https://github.com/nushell/nushell/pull/7906), and [Remove unused `nu-test-support` in `nu-table`](https://github.com/nushell/nushell/pull/7905), and [Update reedline for pre-release testing](https://github.com/nushell/nushell/pull/7903), and [Version bump for `0.75` release](https://github.com/nushell/nushell/pull/7902), and [Bump to `0.74.1` development version](https://github.com/nushell/nushell/pull/7721)
- dependabot[bot] created [Bump windows from 0.43.0 to 0.44.0](https://github.com/nushell/nushell/pull/7911), and [Bump serial_test from 0.10.0 to 1.0.0](https://github.com/nushell/nushell/pull/7910), and [Bump roxmltree from 0.16.0 to 0.17.0](https://github.com/nushell/nushell/pull/7909), and [Bump typetag from 0.1.8 to 0.2.5](https://github.com/nushell/nushell/pull/7908), and [Bump chrono-tz from 0.6.3 to 0.8.1](https://github.com/nushell/nushell/pull/7907), and [Bump actions-rust-lang/setup-rust-toolchain from 1.3.4 to 1.3.5](https://github.com/nushell/nushell/pull/7840), and [Bump sysinfo from 0.26.4 to 0.27.7](https://github.com/nushell/nushell/pull/7839), and [Bump miette from 5.3.0 to 5.5.0](https://github.com/nushell/nushell/pull/7838), and [Bump shadow-rs from 0.16.3 to 0.20.0](https://github.com/nushell/nushell/pull/7837), and [Bump rayon from 1.5.3 to 1.6.1](https://github.com/nushell/nushell/pull/7836), and [Bump scraper from 0.13.0 to 0.14.0](https://github.com/nushell/nushell/pull/7835), and [Bump regex from 1.6.0 to 1.7.1](https://github.com/nushell/nushell/pull/7833), and [Bump git2 from 0.16.0 to 0.16.1](https://github.com/nushell/nushell/pull/7807), and [Bump libgit2-sys from 0.14.1+1.5.0 to 0.14.2+1.5.1](https://github.com/nushell/nushell/pull/7806), and [Bump bumpalo from 3.11.0 to 3.12.0](https://github.com/nushell/nushell/pull/7805), and [Bump actions/stale from 3 to 6](https://github.com/nushell/nushell/pull/7770), and [Bump serial_test from 0.8.0 to 0.10.0](https://github.com/nushell/nushell/pull/7769), and [Bump quick-xml from 0.25.0 to 0.27.1](https://github.com/nushell/nushell/pull/7768), and [Bump dialoguer from 0.9.0 to 0.10.3](https://github.com/nushell/nushell/pull/7765), and [Bump uuid from 1.1.2 to 1.2.2](https://github.com/nushell/nushell/pull/7734), and [Bump once_cell from 1.16.0 to 1.17.0](https://github.com/nushell/nushell/pull/7732), and [Bump git2 from 0.15.0 to 0.16.0](https://github.com/nushell/nushell/pull/7731)
- jntrnr created [Use clippy-recommended simplification](https://github.com/nushell/nushell/pull/7904), and [Add 'enumerate' command for enumeration](https://github.com/nushell/nushell/pull/7871)
- merelymyself created [make `parse -r` columns return 0-indexed uncapitalised](https://github.com/nushell/nushell/pull/7897), and [let `find` take linebreaks into account in `Value::String`](https://github.com/nushell/nushell/pull/7789), and [convert SyntaxShape::Table into the corresponding Type](https://github.com/nushell/nushell/pull/7781)
- WindSoilder created [make help commands search term don't generate $nothing](https://github.com/nushell/nushell/pull/7896), and [refactor: use `input_handler::operate` in ansi_strip command](https://github.com/nushell/nushell/pull/7888), and [mention `do` in `complete` command's doc](https://github.com/nushell/nushell/pull/7884), and [improve doc about flatten](https://github.com/nushell/nushell/pull/7856), and [Let redirection keep exit code](https://github.com/nushell/nushell/pull/7848), and [Fix multi-line redirection inside a block](https://github.com/nushell/nushell/pull/7808), and [dependency update: update polar to 0.26.1](https://github.com/nushell/nushell/pull/7743)
- Hofer-Julian created [Add Github Actions workflow to check for typos](https://github.com/nushell/nushell/pull/7892), and [Extract `gather_commandline_args`](https://github.com/nushell/nushell/pull/7868), and [Reduce again the number of match calls](https://github.com/nushell/nushell/pull/7815), and [Reduce number of `match` calls](https://github.com/nushell/nushell/pull/7813), and [Extract manual `PWD` extraction with method `current_work_dir`](https://github.com/nushell/nushell/pull/7812), and [Clean up `nu-cli/src/eval_file.rs`](https://github.com/nushell/nushell/pull/7804), and [Move all functions of main.rs into modules](https://github.com/nushell/nushell/pull/7803), and [Cleanup of `src/main.rs`](https://github.com/nushell/nushell/pull/7801)
- bobhy created [Support extended unicode escapes in strings: "\u{10fff}"](https://github.com/nushell/nushell/pull/7883)
- rgwood created [Name threads](https://github.com/nushell/nushell/pull/7879), and [Remove 🆖 comments](https://github.com/nushell/nushell/pull/7877), and [Clean up `cd.rs`](https://github.com/nushell/nushell/pull/7876), and [Re-enable some good tests, remove some bad tests](https://github.com/nushell/nushell/pull/7875), and [Fix the build after #7204](https://github.com/nushell/nushell/pull/7857), and [Trim quotes when shelling out to cmd.exe](https://github.com/nushell/nushell/pull/7740), and [Combine benchmarks to speed up `cargo bench` build times](https://github.com/nushell/nushell/pull/7722)
- zhiburt created [nu-commands/table (`table -e`) Recognize limited space better](https://github.com/nushell/nushell/pull/7861), and [nu-table: Wrap last column in `table -e`](https://github.com/nushell/nushell/pull/7778)
- SUPERCILEX created [Fix `do` swallowing all output when ignoring errors](https://github.com/nushell/nushell/pull/7859)
- NotLebedev created [To csv fix](https://github.com/nushell/nushell/pull/7850), and [Ansi link](https://github.com/nushell/nushell/pull/7751)
- Dorumin created [Expose filtering by file type in glob](https://github.com/nushell/nushell/pull/7834)
- michel-slm created [[nu-test-support] Gate system locale tests](https://github.com/nushell/nushell/pull/7824)
- VincenzoCarlino created [Feat/7725 url join](https://github.com/nushell/nushell/pull/7823)
- zoechi created [Fix typos](https://github.com/nushell/nushell/pull/7811)
- webbedspace created [Do not list deprecated subcommands in `help <cmd>`](https://github.com/nushell/nushell/pull/7798), and [`benchmark` now pipes input into the closure](https://github.com/nushell/nushell/pull/7776), and [`str length`, `str substring`, `str index-of`, `split words` and `split chars` now use graphemes instead of UTF-8 bytes](https://github.com/nushell/nushell/pull/7752), and [Disallow `encode`'s silent conversion to HTML entities (and add `-i`/`--ignore-errors` flag to re-allow it)](https://github.com/nushell/nushell/pull/7738)
- Kazuki-Ya created [`fetch` -> `http get` and `post` -> `http post`](https://github.com/nushell/nushell/pull/7796)
- zschaffer created [add magenta to ansi command as synonym for purple](https://github.com/nushell/nushell/pull/7785)
- 1Kinoti created [add dedicated `const in pipeline`, `const builtin var` errors](https://github.com/nushell/nushell/pull/7784), and [Allow underscores in integers and floats](https://github.com/nushell/nushell/pull/7759)
- Xoffio created [Fixes Issue 7648 which crashes nushell and happens when an alias name is shorter than the alias command and the alias command is an external command.](https://github.com/nushell/nushell/pull/7779), and [Add test for fix of issue #7754](https://github.com/nushell/nushell/pull/7756)
- DaRacci created [Check all user groups.](https://github.com/nushell/nushell/pull/7775)
- hustcer created [fix some typos](https://github.com/nushell/nushell/pull/7773), and [Fix generated doc for `explore` commands](https://github.com/nushell/nushell/pull/7723)
- afetisov created [Fix typos and use more idiomatic assertions](https://github.com/nushell/nushell/pull/7755)
- nanoqsh created [Detailed message during core dumped](https://github.com/nushell/nushell/pull/7737)
- murex971 created [Add search terms in random and expression categories](https://github.com/nushell/nushell/pull/7736)

## Extension

- Hofer-Julian created [Add another directory where nu might be installed](https://github.com/nushell/vscode-nushell-lang/pull/75)
- fdncred created [get ready for new 1.0 release](https://github.com/nushell/vscode-nushell-lang/pull/74)
- glcraft created [New syntax highlight](https://github.com/nushell/vscode-nushell-lang/pull/73)

## Documentation

- Hofer-Julian created [Reflect the separation of block and closure](https://github.com/nushell/nushell.github.io/pull/757), and [Add separate page for setting Nu as default shell](https://github.com/nushell/nushell.github.io/pull/754), and [Add Github Actions workflow to check typos](https://github.com/nushell/nushell.github.io/pull/753)
- bobhy created [Document \u{x...} unicode escapes](https://github.com/nushell/nushell.github.io/pull/756), and [document 7883 for release notes](https://github.com/nushell/nushell.github.io/pull/755)
- max-nextcloud created [Update rust version requirement in installation](https://github.com/nushell/nushell.github.io/pull/752)
- WindSoilder created [update doc about stdout and stderr](https://github.com/nushell/nushell.github.io/pull/751)
- webbedspace created [Add my changes](https://github.com/nushell/nushell.github.io/pull/747)
- amtoine created [link to default config file in the "explore" page](https://github.com/nushell/nushell.github.io/pull/745), and [remove a broken link in "Introducing nushell" # "Plugins"](https://github.com/nushell/nushell.github.io/pull/744), and [fix a typo on "language", was spelled "langauge"](https://github.com/nushell/nushell.github.io/pull/743)
- rgwood created [Disable prefetch setting](https://github.com/nushell/nushell.github.io/pull/740)
- waldyrious created [Add two style tweaks to improve tables in code blocks](https://github.com/nushell/nushell.github.io/pull/738)
- hustcer created [Refresh commands docs for nu v0.74](https://github.com/nushell/nushell.github.io/pull/736)
- hbt created [fix deprecated cmd](https://github.com/nushell/nushell.github.io/pull/667)

## Nu_Scripts

- Neur1n created [nu_conda: Another Conda module with Better Performance](https://github.com/nushell/nu_scripts/pull/367)
- fdncred created [small tweaks to get panache working again](https://github.com/nushell/nu_scripts/pull/365), and [fix oh-my.nu script after `do` changes in nushell](https://github.com/nushell/nu_scripts/pull/364), and [fix ohmy.nu path handling on windows](https://github.com/nushell/nu_scripts/pull/351), and [add timed_weather that checks the weather at timed intervals](https://github.com/nushell/nu_scripts/pull/349), and [fixed a type-o in the weather script](https://github.com/nushell/nu_scripts/pull/348), and [fix some bugs when on slash](https://github.com/nushell/nu_scripts/pull/342)
- Hofer-Julian created [Fix scoop completions](https://github.com/nushell/nu_scripts/pull/363), and [git-completions: Stop checking `--force-with-lease`](https://github.com/nushell/nu_scripts/pull/362), and [conda: Check if environment exists before activating](https://github.com/nushell/nu_scripts/pull/361), and [Explain how to create an alias for conda activate without a prompt](https://github.com/nushell/nu_scripts/pull/360)
- schrieveslaach created [Fix git checkout/switch completions](https://github.com/nushell/nu_scripts/pull/359), and [Improve git checkout/switch completions](https://github.com/nushell/nu_scripts/pull/358), and [Add git cherry-pick completion](https://github.com/nushell/nu_scripts/pull/355)
- 1Kinoti created [add todo script](https://github.com/nushell/nu_scripts/pull/357)
- amtoine created [FIX: export the `git cherry-pick` completion](https://github.com/nushell/nu_scripts/pull/356)
- zoechi created [Change "list of values" to "list of records" with value and description](https://github.com/nushell/nu_scripts/pull/354), and [Export command to make it use-able](https://github.com/nushell/nu_scripts/pull/353), and [Add completions for Bitwarden CLI client](https://github.com/nushell/nu_scripts/pull/350)
- fj0r created [K8s](https://github.com/nushell/nu_scripts/pull/347), and [ssh kubernetes docker git just nvim](https://github.com/nushell/nu_scripts/pull/327)
- fitzypop created [add git_branch_cleanup.nu script and readme](https://github.com/nushell/nu_scripts/pull/346)
- bobhy created [prompt/full-line.nu -- full width prompt](https://github.com/nushell/nu_scripts/pull/345)
- stormasm created [add a Readme to the make_release directory](https://github.com/nushell/nu_scripts/pull/344)
- kubouch created [Add initial dependency resolver for nu release](https://github.com/nushell/nu_scripts/pull/343)
- TornaxO7 created [adding git aliases](https://github.com/nushell/nu_scripts/pull/337)
- DrakeTDL created [feat(custom-completions): add reflector completions](https://github.com/nushell/nu_scripts/pull/329)
- ldsands created [Add files needed for Poetry custom-completions](https://github.com/nushell/nu_scripts/pull/319)

## reedline

- sholderbach created [Remove unstable rustdoc lint](https://github.com/nushell/reedline/pull/533), and [Bump version for `0.15` release](https://github.com/nushell/reedline/pull/532)
- dgkf created [Allow configuration of multiline prompt color](https://github.com/nushell/reedline/pull/531)
