---
title: Nushell 0.76
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.76 of Nu. This release adds more commands for debugging, multiplication to clone strings, and moves some file formats to a plugin, thanks to better plugin support.
---

# Nushell 0.76

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your command line. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful command line pipelines.

Today, we're releasing version 0.76 of Nu. This release adds more commands for debugging, multiplication to clone strings, and moves some file formats to a plugin, thanks to better plugin support.

<!-- more -->

# Where to get it

Nu 0.76 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.76.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

NOTE: The optional dataframe functionality is available by `cargo install nu --features=dataframe`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release / New features

## Debugging

We've added a few new commands to help with nushell debugging.

- `ast` - The `ast` command works the same as before and produces an ast for any pipeline you give it.

- `debug` - The `debug` command works the same as before and produces some output about nushell values.

- [`explain`](https://github.com/nushell/nushell/pull/7957) - Provides detailed information about pipeline contents in a closure

The explain command attempts to explain to you how the pipeline, in the passed in block, is going to be interpreted. It shows the pipeline and command index, the looked up and found command name, the command argument data type, and argument details, among other things. Note that spans are also included and can be used with `view span`.

![explain command](../assets/images/0_76_explain_cmd.png)

- [`inspect`](https://github.com/nushell/nushell/pull/8028) - Immediately prints out the contents of a pipeline

The purpose of the `inspect` command is to help to debug pipelines. It works by allowing you to inject the `inspect` command into a pipeline at any point. Then it shows you what the input description is and what the input values are that are passed into `inspect`. With each step it prints this information out while also passing the value information on to the next step in the pipeline.

![inspect command](../assets/images/0_76_inspect_cmd.png)

- `metadata` - The `metadata` command works the same as before.

- [`profile`](https://github.com/nushell/nushell/pull/7854) - Recursively profile pipelines and pipeline elements within a closure.

Enables fine-grained profiling of individual pipeline elements and recursively stepping into blocks/closures. The recursion depth can be controlled (default is 1) and it can optionally collect the profiled source segments for easier orientation and value in each step for easier debugging.

![profile_prompt](../assets/images/0_76_profile_prompt.png)

_Note: There are known limitations that the profiler can't run. For example, it can't collect data from subexpressions and loop iterations. It is caused by profiling data being collected as pipeline metadata and a known bug that pipeline metadata is not preserved in some cases._

- [`timeit`](https://github.com/nushell/nushell/pull/8018) (formerly known as benchmark, same functionality)

```bash
〉timeit { ls | sort-by name type -i | get name }
2ms 509µs 900ns
```

- [`view files`](https://github.com/nushell/nushell/pull/7989) - Lists source code inputs loaded into Nushell since the beginning of the session

`view files` lists the files and entries loaded into nushell's EngineState memory. Note the spans, for use with `view span` and the size of each file's contents stored.

![explain command](../assets/images/0_76_view_files.png)

- [`view source`](https://github.com/nushell/nushell/pull/7989) (formerly known as `view-source`, same functionality)

```bash
〉def my-cmd [arg] { echo $arg }
〉my-cmd hi
hi
〉view source my-cmd
def my-cmd [ arg:any --help (-h) ] { echo $arg }
```

- [`view span`](https://github.com/nushell/nushell/pull/7989) - View contents of a span

Spans are important to nushell. One of their uses is to show where errors are. For instance, in this example below, the leader lines pointing to parts of the command line are able to point to `10`, `/`, and `"bob"` because each of those items have a span.

```bash
〉10 / "bob"
Error: nu::parser::unsupported_operation (link)

  × Types mismatched for operation.
   ╭─[entry #8:1:1]
 1 │ 10 / "bob"
   · ─┬ ┬ ──┬──
   ·  │ │   ╰── string
   ·  │ ╰── doesn't support these values.
   ·  ╰── int
   ╰────
  help: Change int or string to be the right types and try again.
```

### Example usage:

```bash
〉let a = 42
〉$a
42
〉metadata $a | get span
╭───────┬────────╮
│ start │ 113226 │
│ end   │ 113228 │
╰───────┴────────╯
〉view span 113226 113228
42
```

You can also find spans by using the `debug --raw` command.

```bash
〉$env.config | get keybindings | first | debug -r
... bunch of stuff
                    span: Span {
                        start: 68065,
                        end: 68090,
                    },
                },
            ],
            span: Span {
                start: 68050,
                end: 68101,
            },
        },
    ],
    span: Span {
        start: 67927,
        end: 68108,
    },
}

〉view span 67927 68108
{
    name: clear_everything
    modifier: control
    keycode: char_l
    mode: emacs
    event: [
        { send: clearscrollback }
    ]
}

〉view span 68065 68090
{ send: clearscrollback }

〉view span 68050 68101
[
    { send: clearscrollback }
]
```

In an effort to have a little more organization, we've assigned a category of `Debug` to all commands that participate in nushell script debugging. Here is a list of commands that are in that category now.

- ast
- debug
- explain
- inspect
- metadata
- profile
- timeit
- view
- view files
- view source
- view span

## "Multiplication" of strings and lists is now supported. ([WindSoilder](https://github.com/nushell/nushell/pull/8061))

Like in Python you can now use the multiplication operator `*` to create `n` concatenated copies of a string or list.
Here `n` has to be an `int` value.

This can be useful if you want to quickly build ASCII art :)!
Note that the operation is commutative.

```bash
〉" NU " * 3
 NU  NU  NU
〉3 * Shell
ShellShellShell
```

In the same spirit you can use it to quickly create lists with repeatedly the same element.

```bash
/home/stefan/nushell〉7 * [11]
╭───┬────╮
│ 0 │ 11 │
│ 1 │ 11 │
│ 2 │ 11 │
│ 3 │ 11 │
│ 4 │ 11 │
│ 5 │ 11 │
│ 6 │ 11 │
╰───┴────╯
```

::: tip Community Question
We are interested in your feedback regarding the list multiplication. Does this match your expectations or do you want to use this operator overload more often to do scalar multiplication and look for numerical broadcasting support. Let us know!
:::

## Dataframe commands are again explicitly separated from core nushell commands. ([#7998](https://github.com/nushell/nushell/pull/7998))

::: warning NOTE
The optional dataframe functionality is available by `cargo install nu --features=dataframe` or a distribution that includes that feature.
:::

Dataframe commands have all been renamed in order to avoid confusion with nushell commands. It also makes our help commands less confusing. For instance, you can now do `help select` and understand how to use the traditional nushell select command and you can do `help dfr select` and understand how to use the dataframe specific select command.
Previously this was a source of cryptic error messages that were confusing to users.

## `PATH` vs `Path` ([#8003](https://github.com/nushell/nushell/pull/8003))

We fixed a `PATH` vs. `Path` bug in completions, so now you should be able to do commands like `cod<tab>` and get completions like `code` and `code.cmd` across all operating systems.

## More commands become plugins and plugins get first-class help support (WindSoilder, [#7984](https://github.com/nushell/nushell/pull/7984), [#7942](https://github.com/nushell/nushell/pull/7942))

In an effort to both make the core nushell binary smaller and to improve our plugins system along the way we moved the commands for several less common file formats to `nu_plugin_formats`.

To make sure you still have a first-class experience while using these commands, our plugins can now support code examples in the `help` and `F1` menu.

![Plugin nu_plugin_formats shows the help for from ini](../assets/images/0_76_plugin_with_example.png)

As a result, plugin authors need to slightly update their command `Signature` to `PluginSignature` which supports the examples and recompile.

## Improved error messages for int and string literals

Nushell now gives more specific and helpful messages when it detects syntax errors. In this release we've improved errors for `string` and `int` literals but we hope to improve more in the future. [#7952](https://github.com/nushell/nushell/pull/7952)

Errors in the format of escapes within double-quoted strings are reported specifically:

<table>
<tr>
<th>Before</th>
<th>After</th>
</tr>
 <tr>
 <td>

```
------------------------------------------
# Invalid 2 character escape
------------------------------------------
〉"bad: \z"
Error: nu::parser::parse_mismatch (link)

  × Parse mismatch during operation.
   ╭─[entry #19:1:1]
 1 │ "bad: \z"
   · ────┬────
   ·     ╰── expected any shape
   ╰────


------------------------------------------
# Invalid unicode escape
------------------------------------------
〉"bad: \u{1fbogus}"
Error: nu::parser::parse_mismatch (link)

  × Parse mismatch during operation.
   ╭─[entry #21:1:1]
 1 │ "bad: \u{1fbogus}"
   · ─────────┬────────
   ·          ╰── expected any shape
   ╰────
```

 </td>
 <td>

```
-------------------------------------------------------
# Invalid 2 character escape
-------------------------------------------------------
〉"bad: \z"
Error:
  × Invalid literal
   ╭─[entry #18:1:1]
 1 │ "bad: \z"
   ·       ─┬─
   ·        ╰── unrecognized escape after '\' in string
   ╰────



-------------------------------------------------------
# Invalid unicode escape
-------------------------------------------------------
〉"bad: \u{1fbogus}"
Error:
  × Invalid literal
   ╭─[entry #20:1:1]
 1 │ "bad: \u{1fbogus}"
   ·       ──────┬─────
   ·             ╰── invalid unicode escape '\u{X...}',
   .             must be 1-6 hex digits, max value 10FFFF in string
   ╰────
```

</td>
</tr>
</table>

Invalid digits in radix-prefixed int literals are now flagged as a specific error. The old parser treated these invalid ints as bare strings:

<table>
<tr>
<th>Before</th>
<th>After</th>
 </tr>
 <tr>
 <td>

```
------------------------------------------------------
# invalid radix-prefixed integer literals
------------------------------------------------------
〉( 0 + 0x22bogus ) # hex int literal
Error: nu::parser::unsupported_operation (link)

 × Types mismatched for operation.
  ╭─[entry #26:1:1]
1 │ ( 0 + 0x22bogus ) # hex int literal
  ·   ┬ ┬ ────┬────
  ·   │ │     ╰── string
  ·   │ ╰── doesn't support these values.
  ·   ╰── int
  ╰────
 help: Change int or string to be the right types and
       try again.

```

</td>
 <td>

```
--------------------------------------------------------
# invalid radix-prefixed integer literals
--------------------------------------------------------
〉( 0 + 0x22bogus ) # hex int literal
Error:
  × Invalid literal
   ╭─[entry #24:1:1]
 1 │ ( 0 + 0x22bogus ) # hex int literal
   ·       ────┬────
   ·           ╰── invalid digits for radix 16 in int
   ╰────






```

</td>

</tr>
</table>

## General housekeeping in the Nu codebase (Hofer-Julian, fdncred, rgwood, sholderbach)

We are very lucky that we recently had a number of new contributors starting to help out with bug fixes and improvements to Nushell. We want to thank you and want to welcome you all!

In the background a number of contributors spent some time improving and refactoring the [codebase](https://github.com/nushell/nushell) to get us up-to-date and make it more approachable for newcomers.
This includes work to break up less readable code in important places, and a significant effort to get us up-to-speed on some coding standards.
We also updated a number of dependencies and want to continue to improve our dependency tree. We recently enlisted the relentless help of the dependabot.
Furthermore, we enabled rudimentary tracking of test coverage through `codecov.io`. This should help us identify areas were additional tests are needed and can be a great contribution to the project.

# Breaking changes

- `load-env` can not accidentally set `$env.PWD` anymore ([#7963](https://github.com/nushell/nushell/pull/7963))
- The `--numbered` flag to enumerate entries has been removed from `each`, `par-each`, `each while`, and `reduce`. Use the `enumerate` command added in 0.75 instead. ([#7777](https://github.com/nushell/nushell/pull/7777))
- Plugin system: `nu_plugin::Plugin::signature` has changed from `fn signature(&self) -> Vec<Signature>` to `fn signature(&self) -> Vec<PluginSignature>` to support examples on plugin commands. Plugin authors have to update the relative structure to apply these changes. Normally you just need to perform a global search/replace from `Signature` to `PluginSignature`, then rebuild and run with the latest nushell version. ([#7984](https://github.com/nushell/nushell/pull/7984))
- `benchmark` renamed to `timeit` ([#8018](https://github.com/nushell/nushell/pull/8018))
- `dataframe` commands renamed with a prefix of `dfr` ([#7998](https://github.com/nushell/nushell/pull/7998))
- `view-source` renamed to `view source` ([#7989](https://github.com/nushell/nushell/pull/7989))
- Plugin commands can now include examples, which necessitated a change to the plugin signature, which causes all plugins to need to be recompiled for use. ([#7984](https://github.com/nushell/nushell/pull/7984))
- `str lpad` and `str rpad` have been superceeded by `fill` in order to provide alignment ([7846](https://github.com/nushell/nushell/pull/7846))
- `from ini`, `from vcf`, `from ics`, `from eml` commands are moved to plugin called `nu_plugin_formats` to reduce the number of commands in nushell core, you need to install and register the plugin manually to use these command. ([#7942](https://github.com/nushell/nushell/pull/7942))
- `http get` `-t`,`--timeout` parameter is now `-m`,`--max-time` ([8088](https://github.com/nushell/nushell/pull/8088))
- Filesystem commands now print to stderr when using `--verbose` flag ([8014](https://github.com/nushell/nushell/pull/8014))
- The `parse` command will now create 0 indexed columns instead of 1 indexed ([7897](https://github.com/nushell/nushell/pull/7897))

# Full changelog

## Nushell

- amtoine created [TEST: add the output to the new `with-env` example](https://github.com/nushell/nushell/pull/8148), and [DOCUMENTATION: add a new "key-value" example to `with-env`](https://github.com/nushell/nushell/pull/8119), and [remove the `--encoding` option from `register` in the examples](https://github.com/nushell/nushell/pull/8038)
- sholderbach created [Pin `reedline` to `0.16.0`](https://github.com/nushell/nushell/pull/8142), and [Add a script to generate coverage locally](https://github.com/nushell/nushell/pull/8125), and [Bump version for `0.76.0` release](https://github.com/nushell/nushell/pull/8121), and [Make patch coverage check informational only](https://github.com/nushell/nushell/pull/8069), and [Add a `codecov.yml` configuration](https://github.com/nushell/nushell/pull/8059), and [Disable auto-benchmark harness for crates](https://github.com/nushell/nushell/pull/8057), and [Minor clippy: inline format string](https://github.com/nushell/nushell/pull/8043), and [Fix imported virtualenv testsuite](https://github.com/nushell/nushell/pull/8001), and [Test return in `reduce` closure from #7961](https://github.com/nushell/nushell/pull/7973), and [Fix `def-env` docs according to docs#761](https://github.com/nushell/nushell/pull/7972), and [Fix code in benchmarks](https://github.com/nushell/nushell/pull/7949), and [Another shot at trying to setup codecov](https://github.com/nushell/nushell/pull/7948)
- fdncred created [update code coversage script to work better with windows](https://github.com/nushell/nushell/pull/8141), and [show more informaiton when there are toml errors](https://github.com/nushell/nushell/pull/8140), and [update link to command reference](https://github.com/nushell/nushell/pull/8111), and [update colors in dark theme](https://github.com/nushell/nushell/pull/8090), and [fix rename when it is passed an empty column list to rename](https://github.com/nushell/nushell/pull/8086), and [allow date grouping in group-by](https://github.com/nushell/nushell/pull/8084), and [move ast command to the debug group](https://github.com/nushell/nushell/pull/8077), and [relocate debug commands](https://github.com/nushell/nushell/pull/8071), and [update cargo wix to 0.3.4](https://github.com/nushell/nushell/pull/8048), and [add benchmark to deprecated commands](https://github.com/nushell/nushell/pull/8046), and [add a new inspect command for more debugging](https://github.com/nushell/nushell/pull/8028), and [Make metadata a `Category::Debug` command](https://github.com/nushell/nushell/pull/8019), and [rename benchmark to timeit](https://github.com/nushell/nushell/pull/8018), and [fix completions PATH vs Path](https://github.com/nushell/nushell/pull/8003), and [Add dfr to dataframe cmds](https://github.com/nushell/nushell/pull/7998), and [view span & view files commands](https://github.com/nushell/nushell/pull/7989), and [report which datetime couldn't be converted](https://github.com/nushell/nushell/pull/7980), and [explain command](https://github.com/nushell/nushell/pull/7957), and [clean up the registry query output](https://github.com/nushell/nushell/pull/7939), and [add ability to view-source on closures](https://github.com/nushell/nushell/pull/7935), and [A `fill` command to replace `str lpad` and `str rpad`](https://github.com/nushell/nushell/pull/7846)
- WindSoilder created [add usage for plugin commands](https://github.com/nushell/nushell/pull/8138), and [update nu_plugin_python due to signature changes](https://github.com/nushell/nushell/pull/8107), and [support multiplication operation on string and list values](https://github.com/nushell/nushell/pull/8061), and [Make plugin commands support examples.](https://github.com/nushell/nushell/pull/7984), and [Move some `from xxx` commands to plugin](https://github.com/nushell/nushell/pull/7942), and [make do -i works with liststream](https://github.com/nushell/nushell/pull/7889)
- bobhy created [`string | fill` counts clusters, not graphemes; and doesn't count ANSI escape codes](https://github.com/nushell/nushell/pull/8134), and [Improve error when regex rejects pattern. Resolution of #8037](https://github.com/nushell/nushell/pull/8050), and [Syntax errors for string and int](https://github.com/nushell/nushell/pull/7952)
- dependabot[bot] created [Bump actions-rust-lang/setup-rust-toolchain from 1.3.7 to 1.4.2](https://github.com/nushell/nushell/pull/8133), and [Bump sysinfo from 0.27.7 to 0.28.0](https://github.com/nushell/nushell/pull/8132), and [Bump winreg from 0.10.1 to 0.11.0](https://github.com/nushell/nushell/pull/8128), and [Bump roxmltree from 0.17.0 to 0.18.0](https://github.com/nushell/nushell/pull/8065), and [Bump rstest from 0.15.0 to 0.16.0](https://github.com/nushell/nushell/pull/8064), and [Bump proptest from 1.0.0 to 1.1.0](https://github.com/nushell/nushell/pull/8063), and [Bump openssl-src from 111.22.0+1.1.1q to 111.25.0+1.1.1t](https://github.com/nushell/nushell/pull/8011), and [Bump actions-rust-lang/setup-rust-toolchain from 1.3.5 to 1.3.7](https://github.com/nushell/nushell/pull/7979), and [Bump fs_extra from 1.2.0 to 1.3.0](https://github.com/nushell/nushell/pull/7976), and [Bump ical from 0.7.0 to 0.8.0](https://github.com/nushell/nushell/pull/7975), and [Bump which from 4.3.0 to 4.4.0](https://github.com/nushell/nushell/pull/7974), and [Bump tokio from 1.24.1 to 1.25.0](https://github.com/nushell/nushell/pull/7958)
- zhiburt created [Add colors in `table --collapse`](https://github.com/nushell/nushell/pull/8120), and [nu-table/ Fix table --expand issue when table with no header involved ](https://github.com/nushell/nushell/pull/8045), and [nu-table/ table --collapse style fix](https://github.com/nushell/nushell/pull/8041), and [Address #7997](https://github.com/nushell/nushell/pull/8000)
- kubouch created [Revert #7779 (enables back subcommand completions)](https://github.com/nushell/nushell/pull/8102), and [Fix hidden env vars not being hidden in closures](https://github.com/nushell/nushell/pull/8055), and [Reorder `help <keyword>` priority](https://github.com/nushell/nushell/pull/7929), and [Benchmark each pipeline element](https://github.com/nushell/nushell/pull/7854)
- jaudiger created [Factorize HTTP commands code](https://github.com/nushell/nushell/pull/8088), and [http: add `--insecure` flag to `http get`, share common code](https://github.com/nushell/nushell/pull/7992), and [Update few examples of math commands](https://github.com/nushell/nushell/pull/7987), and [Use imported names in `Command::run` signatures](https://github.com/nushell/nushell/pull/7967)
- stormasm created [remove spurious use from default_context.rs](https://github.com/nushell/nushell/pull/8073)
- jntrnr created [Bare word improvements](https://github.com/nushell/nushell/pull/8066)
- ryand67 created [#8027 Hide implementation details in invalid cd call](https://github.com/nushell/nushell/pull/8049)
- rgwood created [Check ctrl+c when collecting a RawStream](https://github.com/nushell/nushell/pull/8020), and [Make ++ operator work with strings and binary values](https://github.com/nushell/nushell/pull/8017), and [Windows: handle illegal filenames a little better](https://github.com/nushell/nushell/pull/7999), and [Fix $nu path separators on Windows](https://github.com/nushell/nushell/pull/7996), and [Add comment explaining background thread usage for plugin calls](https://github.com/nushell/nushell/pull/7878)
- NotLebedev created [Filesystem commands print --verbose to stderr](https://github.com/nushell/nushell/pull/8014)
- initinll created [Added fix for #7981 - Replaced crate serde_ini with rust-ini for package nu-command/from](https://github.com/nushell/nushell/pull/8009), and [Added fix for #7970 - Upgraded toml crate version from version from 0.5.8 to 0.7.1 for package nu-command](https://github.com/nushell/nushell/pull/7990)
- bgeron created [Clarify two config fields](https://github.com/nushell/nushell/pull/7969)
- Hofer-Julian created [Extract run blocks into functions](https://github.com/nushell/nushell/pull/7964), and [Fix copy paste error](https://github.com/nushell/nushell/pull/7945)
- Mehrbod2002 created [Load env pwd](https://github.com/nushell/nushell/pull/7963), and [Validate input range of `du` flags](https://github.com/nushell/nushell/pull/7962), and [Fix: dst error on cp command](https://github.com/nushell/nushell/pull/7895)
- nabacg created [return in reduce command closure](https://github.com/nushell/nushell/pull/7961)
- webbedspace created [Only abbreviate to "[table x rows]" if every value is a record](https://github.com/nushell/nushell/pull/7922), and [Remove deprecated `--numbered` flag from four commands](https://github.com/nushell/nushell/pull/7777)
- csko created [use newer reedline (once available)](https://github.com/nushell/nushell/pull/7919), and [respect use_ansi_coloring configuration](https://github.com/nushell/nushell/pull/7912)
- merelymyself created [allow `parse` to work better with streams](https://github.com/nushell/nushell/pull/7870), and [ensure that when nu evaluates files, it allows early returns](https://github.com/nushell/nushell/pull/7415)
- dmatos2012 created [Support URLs in `start` command](https://github.com/nushell/nushell/pull/7799)

## Extension

- glcraft created [Fix `use` syntax ](https://github.com/nushell/vscode-nushell-lang/pull/79)
- kecrily created [feat: add icon for `.nu` extension in VS Code](https://github.com/nushell/vscode-nushell-lang/pull/77)

## Documentation

- WindSoilder created [Add breaking change](https://github.com/nushell/nushell.github.io/pull/790), and [Add breaking change for plugin signature](https://github.com/nushell/nushell.github.io/pull/775)
- Hofer-Julian created [Prepare for generation of categories](https://github.com/nushell/nushell.github.io/pull/789), and [Move `book/commands` to `commands/commands`](https://github.com/nushell/nushell.github.io/pull/785), and [Move command reference to navbar](https://github.com/nushell/nushell.github.io/pull/782)
- hustcer created [fix #768 for zh-CN translation](https://github.com/nushell/nushell.github.io/pull/787), and [fix `all` and `any` usage examples, close #758](https://github.com/nushell/nushell.github.io/pull/786), and [fix #781 and update some node modules](https://github.com/nushell/nushell.github.io/pull/783), and [Update some vuepress plugins](https://github.com/nushell/nushell.github.io/pull/771), and [Update typos config and fix some typos](https://github.com/nushell/nushell.github.io/pull/762), and [feat: refresh command docs for nu v0.75](https://github.com/nushell/nushell.github.io/pull/760)
- msmart created [Fix typos in plugins.md](https://github.com/nushell/nushell.github.io/pull/780)
- kubouch created [Add `profile` note and screenshot](https://github.com/nushell/nushell.github.io/pull/778)
- bobhy created [release notes for #7952](https://github.com/nushell/nushell.github.io/pull/777)
- jafriyie1 created [Fix: updating pages that used each -n command](https://github.com/nushell/nushell.github.io/pull/776), and [Fix changed history command to match default in config](https://github.com/nushell/nushell.github.io/pull/773)
- FilipAndersson245 created [replaces fetch with http in varius places](https://github.com/nushell/nushell.github.io/pull/769), and [Updated cookbook with http get instead of fetch.](https://github.com/nushell/nushell.github.io/pull/763)
- das-g created [[pt-BR] fix statement about `lines` output type ("tabela"→"lista")](https://github.com/nushell/nushell.github.io/pull/766), and [[es] fix statement about `lines` output type ("tabla"→"lista")](https://github.com/nushell/nushell.github.io/pull/765), and [fix statement about `lines` output type ("table"→"list")](https://github.com/nushell/nushell.github.io/pull/764)

## Nu_Scripts

- sholderbach created [Update release script to `nu_plugin_formats`](https://github.com/nushell/nu_scripts/pull/384)
- amtoine created [FEATURE: export all the math functions to use them in `nushell`](https://github.com/nushell/nu_scripts/pull/382), and [FIX: the math functions can not be `use`d](https://github.com/nushell/nu_scripts/pull/381)
- fdncred created [just a base64 encoder written for fun](https://github.com/nushell/nu_scripts/pull/380), and [update scripts from fetch to http get](https://github.com/nushell/nu_scripts/pull/373)
- hyiltiz created [Fix space-in-path issue and extra / at root](https://github.com/nushell/nu_scripts/pull/379), and [Fix abbrev logic](https://github.com/nushell/nu_scripts/pull/375), and [Update to 0.75.1 syntax](https://github.com/nushell/nu_scripts/pull/371)
- maxim-uvarov created [add a current session history menu](https://github.com/nushell/nu_scripts/pull/378)
- Tiggax created [Updated the temp.nu for 0.60.0+](https://github.com/nushell/nu_scripts/pull/377), and [Update Check-if-env-exsists to use the envs_dirs from conda info](https://github.com/nushell/nu_scripts/pull/376)
- WindSoilder created [update themes' readme](https://github.com/nushell/nu_scripts/pull/372)
- Neur1n created [added nu_msvs module](https://github.com/nushell/nu_scripts/pull/370)

## reedline

- sholderbach created [Bump version for `0.16.0` release.](https://github.com/nushell/reedline/pull/542), and [Bump `rstest` to 0.16](https://github.com/nushell/reedline/pull/541)
- rgwood created [VACUUM after deleting SQLite data](https://github.com/nushell/reedline/pull/538), and [Add History::clear() function](https://github.com/nushell/reedline/pull/536)
- fdncred created [add history-clear to demo](https://github.com/nushell/reedline/pull/537)
- csko created [Fix columnar menu completion corrupting the editor insertion point](https://github.com/nushell/reedline/pull/534)
