---
title: Nushell 0.77
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.77 of Nu. This release adds reworked aliases, more consistent timestamp handling, reworked XML support, and more.
---

# Nushell 0.77

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your command line. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful command line pipelines.

Today, we're releasing version 0.77 of Nu. This release adds reworked aliases, more consistent timestamp handling, reworked XML support, and more.

<!-- more -->

# Where to get it

Nu 0.77 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.77.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

NOTE: The optional dataframe functionality is available by `cargo install nu --features=dataframe`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release / New features

## Reworked aliases (Breaking changes!) ([kubouch](https://github.com/nushell/nushell/pull/8123))

Aliases have been a constant source of panics and growing code complexity as a result of trying to patch the panics. In this release, we re-implement aliases from scratch. Instead of replacing spans of expressions, aliases are implemented as another type of command, quite like `extern` is used to implement known externals. Alias is a command that wraps another command call. As a result, in some cases, aliases do not behave exactly the same as before. Here are the key facts:

- Alias can only alias another command call. For example, `alias la = ls -a` works, but the following does not:
  - `alias foo = "foo"`
    - `"foo"` is not a command call, use `alias foo = echo "foo"` instead
  - `alias lsn = (ls | sort-by type name -i)`
    - subexpression is not a command call, use a custom command instead
- Alias cannot alias command named the same as the alias. E.g., `alias ls = ls -a` is not possible currently, and gives an unhelpful error message. We plan to fix this as soon as possible and in the future we aim for this to work.
- Some parser keywords are not allowed to be aliased. Currently, `overlay` commands can be aliased but the other parser keywords can not. We can add support for aliasing more parser keywords in the future.

If some of the above is too limiting for you, the old aliases are still unchanged and available as `old-alias`. Just change `alias` to `old-alias` and it should work the same as before. If there are no more problems with the new alias implementation, and we manage to iron out the recursive alias issue, we will remove `old-alias` in the next release, otherwise, we'll keep it around longer.

## More consistent timestamp handling ([bobhy](https://github.com/nushell/nushell/pull/8337))

Simplified conversion between Nushell `date` type and unix timestamps ([#8244](https://github.com/nushell/nushell/pull/8244)).

Nushell now standardizes on representing a Unix timestamp as a number of _nanoseconds_ relative to the unix epoch 1970-01-01 00:00:00 +0000 (UTC). Since the timestamp is stored in a (64 bit signed) Nushell `int` type, this limits the range of dates that can be represented to approximately 21-sep-1677 through 11-apr-2262.

In prior versions, Nushell attempted to extend the range of representable dates by allowing multiple resolutions of timestamps (seconds, milliseconds as well as nanoseconds) to be stored and relied on arbitrary range check heuristics to disambiguate the value intended. However, there were bugs in the checks and incorrect results could be produced.

With this change `<int> | into datetime` assumes the input is a number of nanoseconds and can never produce a date outside this range:

```rust
〉"7fffffffffffffff" | into int -r 16 | into datetime
Fri, 11 Apr 2262 23:47:16 +0000 (in 239 years)
〉("7fffffffffffffff" | into int -r 16) * -1 | into datetime
Tue, 21 Sep 1677 00:12:43 +0000 (345 years ago)
```

The timestamp epoch is the standard unix epoch. Note the timezone is UTC/GMT:

```rust
〉0 | into datetime
Thu, 01 Jan 1970 00:00:00 +0000 (53 years ago)
```

`<datetime> | into int` can now produce an error if the input is outside the supported range:

```rust
〉1492-10-12 | into int
Error: nu::shell::incorrect_value

  × Incorrect value.
   ╭─[entry #51:1:1]
 1 │ 1492-10-12 | into int
   ·              ────┬───
   ·                  ╰── DateTime out of timestamp range 1677-09-21T00:12:43 and 2262-04-11T23:47:16
   ╰────
```

And finally, although not strictly required by the above fix, `<date> | date to-record` and `<date> | date to-table` now have a `nanosecond` field containing the subsecond residue of the input value (however it was produced).

```rust
〉"7fffffffffffffff" | into int -r 16 | into datetime | date to-record
╭────────────┬───────────╮
│ year       │ 2262      │
│ month      │ 4         │
│ day        │ 11        │
│ hour       │ 23        │
│ minute     │ 47        │
│ second     │ 16        │
│ nanosecond │ 854775807 │
│ timezone   │ +00:00    │
╰────────────┴───────────╯
〉"7fffffffffffffff" | into int -r 16 | into datetime | date to-table
╭───┬──────┬───────┬─────┬──────┬────────┬────────┬────────────┬──────────╮
│ # │ year │ month │ day │ hour │ minute │ second │ nanosecond │ timezone │
├───┼──────┼───────┼─────┼──────┼────────┼────────┼────────────┼──────────┤
│ 0 │ 2262 │     4 │  11 │   23 │     47 │     16 │  854775807 │ +00:00   │
╰───┴──────┴───────┴─────┴──────┴────────┴────────┴────────────┴──────────╯
```

## New XML format ([NotLebedev](https://github.com/nushell/nushell/pull/7947))

New format for xml data created and accepted by `from xml` and `to xml` commands ([#7947](https://github.com/nushell/nushell/pull/7947)).

Commands `from xml` and `to xml` now use format where each xml entry is represented by a single `{tag: <tag name> attributes: <tag attributes> content: [<child entries>]}` record. Special xml entries also use this record, replacing irrelevant fields with `null` for easier use.

Reading some simple xml:

```rust
〉'<release>
    <project repo="https://github.com/nushell/nushell">nushell</project>
    <version>0.77</version>
    <message>Now with better xml!</message>
  </release>' | from xml
╭────────────┬─────────────────────────────────────────────────────────────────────────────────────────────────────────────╮
│ tag        │ release                                                                                                     │
│ attributes │ {record 0 fields}                                                                                           │
│            │ ╭───┬─────────┬───────────────────────────────────────────────┬───────────────────────────────────────────╮ │
│ content    │ │ # │   tag   │                  attributes                   │                  content                  │ │
│            │ ├───┼─────────┼───────────────────────────────────────────────┼───────────────────────────────────────────┤ │
│            │ │ 0 │ project │ ╭──────┬────────────────────────────────────╮ │ ╭───┬─────┬────────────┬─────────╮        │ │
│            │ │   │         │ │ repo │ https://github.com/nushell/nushell │ │ │ # │ tag │ attributes │ content │        │ │
│            │ │   │         │ ╰──────┴────────────────────────────────────╯ │ ├───┼─────┼────────────┼─────────┤        │ │
│            │ │   │         │                                               │ │ 0 │     │            │ nushell │        │ │
│            │ │   │         │                                               │ ╰───┴─────┴────────────┴─────────╯        │ │
│            │ │ 1 │ version │ {record 0 fields}                             │ ╭───┬─────┬────────────┬─────────╮        │ │
│            │ │   │         │                                               │ │ # │ tag │ attributes │ content │        │ │
│            │ │   │         │                                               │ ├───┼─────┼────────────┼─────────┤        │ │
│            │ │   │         │                                               │ │ 0 │     │            │ 0.77    │        │ │
│            │ │   │         │                                               │ ╰───┴─────┴────────────┴─────────╯        │ │
│            │ │ 2 │ message │ {record 0 fields}                             │ ╭───┬─────┬────────────┬────────────────╮ │ │
│            │ │   │         │                                               │ │ # │ tag │ attributes │    content     │ │ │
│            │ │   │         │                                               │ ├───┼─────┼────────────┼────────────────┤ │ │
│            │ │   │         │                                               │ │ 0 │     │            │ Now with       │ │ │
│            │ │   │         │                                               │ │   │     │            │ better xml!    │ │ │
│            │ │   │         │                                               │ ╰───┴─────┴────────────┴────────────────╯ │ │
│            │ ╰───┴─────────┴───────────────────────────────────────────────┴───────────────────────────────────────────╯ │
╰────────────┴─────────────────────────────────────────────────────────────────────────────────────────────────────────────╯
```

Creating a little html page. In case of `to xml` one can deviate from rigid structure and omit
empty fields of records:

```rust
〉{tag: html content: [
  {tag: body content: [
    {tag: h1 content: ['Hello from Nushell !']}
    {tag: a attributes: {href: 'https://www.nushell.sh/'} content: ['Learn more here']}
    {tag: p content: [$"Current time is (date now)"]}
  ]}
  ]} | to xml
<html><body><h1>Hello from Nushell !</h1><a href="https://www.nushell.sh/">Learn more here</a><p>Current time is Mon, 13 Mar 2023 21:20:56 +0300 (now)</p></body></html>
```

## New additions to `$nu` ([StevenDoesStuffs](https://github.com/nushell/nushell/pull/8306), [amtoine](https://github.com/nushell/nushell/pull/8353))

The builtin `$nu` variable now contains new entries:

- `is-interactive`: Nushell was launched in interactive mode
- `is-login`: Nushell was launched in login mode
- `startup_time`: Nushell's startup time

## Reworked `http` subcommands ([jaudiger](https://github.com/nushell/nushell/pull/8135), [jaudiger](https://github.com/nushell/nushell/pull/8144))

The `http` command now has more subcommands and existing subcommands have been reworked:

```
> help http
Various commands for working with http methods.

You must use one of the following subcommands. Using this command as-is will only produce this help message.

Search terms: network, fetch, pull, request, download, curl, wget

Usage:
  > http

Subcommands:
  http delete - Delete the specified resource.
  http get - Fetch the contents from a URL.
  http head - Get the headers from a URL.
  http patch - Patch a body to a URL.
  http post - Post a body to a URL.
  http put - Put a body to a URL.

Flags:
  -h, --help - Display the help message for this command

Signatures:
  <nothing> | http -> <string>
```

Make sure to browse the help messages of these commands. They contain fully functional examples thanks to pointing at www.example.com.

## Examples results are now shown in `help` pages ([amtoine](https://github.com/nushell/nushell/pull/8189))

When commands define expected results for their examples, the output is now shown just below the associated examples.

Let's take the `merge` command as an example!

Before the change, the output of `help merge` would give

```bash
Examples:
  Add an 'index' column to the input table
  > [a b c] | wrap name | merge ( [1 2 3] | wrap index )

  Merge two records
  > {a: 1, b: 2} | merge {c: 3}

  Merge two tables, overwriting overlapping columns
  > [{columnA: A0 columnB: B0}] | merge [{columnA: 'A0*'}]
```

Now, it gives the output of all the example commands:

```bash
Examples:
  Add an 'index' column to the input table
  > [a b c] | wrap name | merge ( [1 2 3] | wrap index )
  ╭───┬──────╮
  │ # │ name │
  ├───┼──────┤
  │ 1 │ a    │
  │ 2 │ b    │
  │ 3 │ c    │
  ╰───┴──────╯

  Merge two records
  > {a: 1, b: 2} | merge {c: 3}
  ╭───┬───╮
  │ a │ 1 │
  │ b │ 2 │
  │ c │ 3 │
  ╰───┴───╯

  Merge two tables, overwriting overlapping columns
  > [{columnA: A0 columnB: B0}] | merge [{columnA: 'A0*'}]
  ╭───┬─────────┬─────────╮
  │ # │ columnA │ columnB │
  ├───┼─────────┼─────────┤
  │ 0 │ A0*     │ B0      │
  ╰───┴─────────┴─────────╯
```

> :bulb: **Note**  
> the website has been modified accordingly with the same outputs.

# Breaking changes

- Alias changes, see above
- Comments on the same line as code now require a space before ` #` to be recognized as such. This allows you to have a string `foo#bar` with a pound sign. ([#8151](https://github.com/nushell/nushell/pull/8151))
- `env` command has been removed, use `$env` instead (https://github.com/nushell/nushell/pull/8185)
- `str trim` no longer has `--all`, `--both`, and `--format` flags. `str replace` should be an adequate replacement; please let us know if it is not ([#8205](https://github.com/nushell/nushell/pull/8205))
- The changes to timestamp handling noted above ([#8244](https://github.com/nushell/nushell/pull/8244)) can require code changes to existing scripts:
  - Saved data containing the results of an old datetime-to-timestamp conversion will _not_ deserialize correctly when read back by the current version of Nushell. In general, Nushell will produce incorrect datetime values without noting an error.
  - `<int> | into datetime` now assumes nanosecond scaling for all timestamps. You must ensure all timestamps computed by your script or retrieved from external sources are scaled appropriately.
  - `<date> | into int` can now fail, as noted above. You cannot rely on this operation to persist a arbitrary date.
- The change to `from xml` and `to xml` commands noted above ([#7947](https://github.com/nushell/nushell/pull/7947)) will require to update scripts relying on old output/input format.
- `mkdir`, `cp`, `mv` and `rm` return `nothing`. Errors and actions with `--verbose` flag are printed to stderr instead ([#8014](https://github.com/nushell/nushell/pull/8014)).
- Plugin authors relying on `nu_protocol::Value` may need to update their code to account for a change to `Value::Error` ([#8375](https://github.com/nushell/nushell/pull/8375))
- Different types of lists can now be appended. This can break scripts that were relying on the stricter behavior (https://github.com/nushell/nushell/pull/8157)

# Full changelog

- sholderbach created [Pin to `reedline` 0.17](https://github.com/nushell/nushell/pull/8441), and [Pin to `nu-ansi-term` 0.47](https://github.com/nushell/nushell/pull/8440), and [Remove unused `nu-json` from `nu-protocol`](https://github.com/nushell/nushell/pull/8417), and [Bump version to `0.77.0`](https://github.com/nushell/nushell/pull/8410), and [Update all dependencies in `Cargo.lock`](https://github.com/nushell/nushell/pull/8408), and [Box `ShellError` in `Value::Error`](https://github.com/nushell/nushell/pull/8375), and [Document and critically review `ShellError` variants - Ep. 3](https://github.com/nushell/nushell/pull/8340), and [Document and critically review `ShellError` variants - Ep. 2](https://github.com/nushell/nushell/pull/8326), and [Fix codecov badge](https://github.com/nushell/nushell/pull/8279), and [Pull bleeding edge virtualenv tests again](https://github.com/nushell/nushell/pull/8262), and [Document and critically review `ShellError` variants - Ep. 1](https://github.com/nushell/nushell/pull/8229), and [Test more datatypes in nuon](https://github.com/nushell/nushell/pull/8211), and [Revert range expansion for `to nuon`](https://github.com/nushell/nushell/pull/8210), and [Add links to the remaining README badges](https://github.com/nushell/nushell/pull/8191), and [Disable Windows coverage tracking for now](https://github.com/nushell/nushell/pull/8190)
- BlacAmDK created [Fix SQLite table creation sql](https://github.com/nushell/nushell/pull/8430)
- jntrnr created [Don't use 'spam' as module name as it isn't unique](https://github.com/nushell/nushell/pull/8409), and [Hack around bad binary viewing logic](https://github.com/nushell/nushell/pull/8399), and [Fix quicktest-found parser crash](https://github.com/nushell/nushell/pull/8394), and [print pipeline contents in `print`](https://github.com/nushell/nushell/pull/8305), and [Remove the 'env' command, as we have the variable](https://github.com/nushell/nushell/pull/8185)
- kubouch created [Disable alias recursion](https://github.com/nushell/nushell/pull/8397), and [Allow aliasing parser keywords](https://github.com/nushell/nushell/pull/8250), and [Move profiling metadata collecting to function](https://github.com/nushell/nushell/pull/8198)
- rgwood created [Remove `get -i` from default env file](https://github.com/nushell/nushell/pull/8390), and [Fix the SQLite feature name in `version`](https://github.com/nushell/nushell/pull/8381), and [Revert to notify v4](https://github.com/nushell/nushell/pull/8367), and [Fix `to json` for SQLite databases](https://github.com/nushell/nushell/pull/8343), and [Remove body parameters from `http get`](https://github.com/nushell/nushell/pull/8336), and [Put a lock around `cargo build` invocations for plugin tests](https://github.com/nushell/nushell/pull/8333), and [Add SSL tests for `http get`](https://github.com/nushell/nushell/pull/8327), and [Fix CPU usage info in `sys`](https://github.com/nushell/nushell/pull/8321), and [Use `for` instead of `each` in register-plugins.nu](https://github.com/nushell/nushell/pull/8284), and [Fix CPU frequency in `sys` output](https://github.com/nushell/nushell/pull/8275), and [Switch http to https in banner](https://github.com/nushell/nushell/pull/8272), and [Simplify `str trim` command](https://github.com/nushell/nushell/pull/8205)
- fdncred created [updates a test to use testbin versus external echo](https://github.com/nushell/nushell/pull/8387), and [fixed an error message that popped up after landing](https://github.com/nushell/nushell/pull/8356), and [point nushell at latest reedline and nu-ansi-term main](https://github.com/nushell/nushell/pull/8342), and [fix ansi example so it is tested](https://github.com/nushell/nushell/pull/8192), and [update the manual msi generation instructions for winget](https://github.com/nushell/nushell/pull/8178), and [remove old winget manual release ci](https://github.com/nushell/nushell/pull/8177)
- klementievdmitry created [Reworking `help aliases`](https://github.com/nushell/nushell/pull/8372)
- bobhy created [add `dirs` command to std lib](https://github.com/nushell/nushell/pull/8368), and [Fix 8244 -- store timestamps with nanosecond resolution (consistently)](https://github.com/nushell/nushell/pull/8337)
- NotLebedev created [Hide 7925](https://github.com/nushell/nushell/pull/8359)
- amtoine created [FEATURE: add the startup time to `$nu`](https://github.com/nushell/nushell/pull/8353), and [FIX: redirect to `encode base64` as `hash bash64` is deprecated](https://github.com/nushell/nushell/pull/8351), and [FEATURE: add the example results to the scope](https://github.com/nushell/nushell/pull/8319), and [DOC: add a `README` to the standard library](https://github.com/nushell/nushell/pull/8304), and [FEATURE: add a `path add` to the standard library](https://github.com/nushell/nushell/pull/8303), and [REFACTOR: move the standard library to a less-confusing place](https://github.com/nushell/nushell/pull/8265), and [REFACTOR: format some example commands](https://github.com/nushell/nushell/pull/8223), and [FEATURE: print example command results in the `help`](https://github.com/nushell/nushell/pull/8189)
- stormasm created [Cratification: Test Infrastructure Support Part One](https://github.com/nushell/nushell/pull/8335), and [remove left over build.rs from nu-command](https://github.com/nushell/nushell/pull/8280), and [clean up nu-cmd-lang Cargo.toml](https://github.com/nushell/nushell/pull/8252), and [cratification: Example support](https://github.com/nushell/nushell/pull/8231), and [Cratification: Break out nu_cmd_lang into a separate crate](https://github.com/nushell/nushell/pull/8181)
- dependabot[bot] created [Bump scraper from 0.14.0 to 0.15.0](https://github.com/nushell/nushell/pull/8331), and [Bump rust-embed from 6.4.1 to 6.6.0](https://github.com/nushell/nushell/pull/8330), and [Bump tempfile from 3.3.0 to 3.4.0](https://github.com/nushell/nushell/pull/8329), and [Bump rayon from 1.6.1 to 1.7.0](https://github.com/nushell/nushell/pull/8328), and [Bump actions/checkout from 2 to 3](https://github.com/nushell/nushell/pull/8240), and [Bump actions-rust-lang/setup-rust-toolchain from 1.4.2 to 1.4.3](https://github.com/nushell/nushell/pull/8239), and [Bump sysinfo from 0.27.7 to 0.28.0](https://github.com/nushell/nushell/pull/8237), and [Bump bytesize from 1.1.0 to 1.2.0](https://github.com/nushell/nushell/pull/8236), and [Bump csv from 1.1.6 to 1.2.0](https://github.com/nushell/nushell/pull/8235), and [Bump procfs from 0.14.1 to 0.15.1](https://github.com/nushell/nushell/pull/8233)
- FilipAndersson245 created [changes Reqwest to Ureq.](https://github.com/nushell/nushell/pull/8320)
- jaudiger created [Resolve Clippy warnings inside tests.](https://github.com/nushell/nushell/pull/8315), and [Update the command 'version'.](https://github.com/nushell/nushell/pull/8312), and [Shadow rs dep](https://github.com/nushell/nushell/pull/8298), and [Uniformize usage() and extra_usage() message ending for commands helper.](https://github.com/nushell/nushell/pull/8268), and [Add unit tests for HTTP commands.](https://github.com/nushell/nushell/pull/8267), and [Fix insecure + max-time arguments for HTTP commands.](https://github.com/nushell/nushell/pull/8266)
- StevenDoesStuffs created [Add is-interactive and is-login to NuVariable and allow running scripts with -i](https://github.com/nushell/nushell/pull/8306)
- johnny-byte created [remove extra allocation from nu-json](https://github.com/nushell/nushell/pull/8299)
- 1Kinoti created [fix `NotAConstant` error help message](https://github.com/nushell/nushell/pull/8293), and [fix: allow subtraction of durations from dates](https://github.com/nushell/nushell/pull/8247)
- ygguser created [README for nu-json. Related to nushell/nushell#8253](https://github.com/nushell/nushell/pull/8289)
- dmatos2012 created [Error out when config.nu has no editor configured](https://github.com/nushell/nushell/pull/8282), and [Error out when Select gets same row](https://github.com/nushell/nushell/pull/8200)
- Vctr-w created [Type mismatch span fix #7288](https://github.com/nushell/nushell/pull/8271)
- ryand67 created [math floor and ceil round to int rather than float #8258](https://github.com/nushell/nushell/pull/8269), and [remove links to `ShellError` and `ParseError` docs - #8167](https://github.com/nushell/nushell/pull/8193)
- alesito85 created [Fixes insecure and timeout flags](https://github.com/nushell/nushell/pull/8255)
- baehyunsol created [remove unnecessary rows in `into datetime --list`](https://github.com/nushell/nushell/pull/8243), and [Update trim\_.rs](https://github.com/nushell/nushell/pull/8201)
- merelymyself created [add case insensitive switch to starts-with and ends-with](https://github.com/nushell/nushell/pull/8221)
- Xoffio created [Ctrl+c interruption - `cp` command](https://github.com/nushell/nushell/pull/8219)
- gustavopmaia created [Add Remove welcome message tutorial](https://github.com/nushell/nushell/pull/8217)
- KoviRobi created [Use `with-env` to avoid calling external command on invalid command](https://github.com/nushell/nushell/pull/8209)
- WindSoilder created [Throw out error if external command in subexpression is failed to run](https://github.com/nushell/nushell/pull/8204)
- Dorumin created [special-case ExternalStream in bytes starts-with](https://github.com/nushell/nushell/pull/8203)
- alextremblay created [move `hash md5` and `hash sha256` commands to the hash category](https://github.com/nushell/nushell/pull/8196)
- Hofer-Julian created [Force install in `install-all` scripts](https://github.com/nushell/nushell/pull/8194)
- SUPERCILEX created [Compress $HOME into ~ in prompt](https://github.com/nushell/nushell/pull/8173)
- zhiburt created [table --collapse dont do truncation return message instead](https://github.com/nushell/nushell/pull/8172)
- Yethal created [Added examples to query web plugin](https://github.com/nushell/nushell/pull/8171)

## Extensions

- fdncred created [next release won't be a preview](https://github.com/nushell/vscode-nushell-lang/pull/85), and [update language, version, changelog](https://github.com/nushell/vscode-nushell-lang/pull/84)
- adhadse created [modified extension.ts to include standard dir for binary files on linux](https://github.com/nushell/vscode-nushell-lang/pull/82)

## Documentation

- kubouch created [Add alias note](https://github.com/nushell/nushell.github.io/pull/824)
- NotLebedev created [Add description for #8205 and #8014](https://github.com/nushell/nushell.github.io/pull/821)
- martinetd created [Fix show_banner config item](https://github.com/nushell/nushell.github.io/pull/820)
- rgwood created [Newbie-friendly command reference header](https://github.com/nushell/nushell.github.io/pull/818)
- bergus created [Dashes instead of underscores in command comparisons](https://github.com/nushell/nushell.github.io/pull/816)
- samrland created [Update externs.md](https://github.com/nushell/nushell.github.io/pull/813)
- amtoine created [FIX: remove ANSI escape sequences when the output is a `string`](https://github.com/nushell/nushell.github.io/pull/812), and [add the example results to the documentation pages](https://github.com/nushell/nushell.github.io/pull/807), and [REFACTOR: add documentation to and clean up the `make_docs.nu` script](https://github.com/nushell/nushell.github.io/pull/803), and [FIX: remove mentions to old and deprecated `&&` and `||` logic operators](https://github.com/nushell/nushell.github.io/pull/802)
- fdncred created [add fish_completer example](https://github.com/nushell/nushell.github.io/pull/811)
- presidento created [Book: add links to commands](https://github.com/nushell/nushell.github.io/pull/810)
- bobhy created [release notes for #8244; don't merge till the fix itself is merged](https://github.com/nushell/nushell.github.io/pull/809)
- kejadlen created [Remove more references to `--numbered`](https://github.com/nushell/nushell.github.io/pull/806), and [Remove mention of `-n` on `each`](https://github.com/nushell/nushell.github.io/pull/805)
- debemdeboas created [Rename $env.PATH to $env.Path to reflect actual shell behavior](https://github.com/nushell/nushell.github.io/pull/801)
- gustavopmaia created [feat: Remove welcome message](https://github.com/nushell/nushell.github.io/pull/799)
- dmatos2012 created [Expand working with lists description](https://github.com/nushell/nushell.github.io/pull/798)
- hustcer created [Add short flags to command docs, fix #509](https://github.com/nushell/nushell.github.io/pull/795), and [Add registry query doc for Windows](https://github.com/nushell/nushell.github.io/pull/794), and [Refresh docs for v0.76](https://github.com/nushell/nushell.github.io/pull/791)
- Hofer-Julian created [Generate categories](https://github.com/nushell/nushell.github.io/pull/793), and [Fix typo](https://github.com/nushell/nushell.github.io/pull/792)

## nu_scripts

- sholderbach created [Add `nu-cmd-lang` to `nu_release.nu`](https://github.com/nushell/nu_scripts/pull/411)
- siph created [Replace deprecated `str collect` command](https://github.com/nushell/nu_scripts/pull/410)
- Tiggax created [Updated conda script to default to base if no arg given](https://github.com/nushell/nu_scripts/pull/409), and [Added Wordle game](https://github.com/nushell/nu_scripts/pull/403)
- fdncred created [Revert "conda activate base if env_name not given"](https://github.com/nushell/nu_scripts/pull/408), and [update scripts that use benchmark to timeit command](https://github.com/nushell/nu_scripts/pull/397), and [update str lpad str rpad to fill](https://github.com/nushell/nu_scripts/pull/396), and [updates for new dfr names](https://github.com/nushell/nu_scripts/pull/389), and [rename misc folder](https://github.com/nushell/nu_scripts/pull/388), and [fix text where comments don't have spaces](https://github.com/nushell/nu_scripts/pull/387)
- Kissaki created [Fix docs typo in job.nu](https://github.com/nushell/nu_scripts/pull/405)
- sgasse created [custom-completions: git: Add `git rebase`](https://github.com/nushell/nu_scripts/pull/404)
- visr created [conda activate base if env_name not given](https://github.com/nushell/nu_scripts/pull/400)
- dedebenui created [`conda.nu` : changed `insert` to `merge`](https://github.com/nushell/nu_scripts/pull/399)
- chtenb created [Make commands optional](https://github.com/nushell/nu_scripts/pull/398)
- WindSoilder created [fix conda script](https://github.com/nushell/nu_scripts/pull/395)
- washanhanzi created [FIX `kubernetes.nu` since str lpad and str rpad are deprecated in 0.76](https://github.com/nushell/nu_scripts/pull/394)
- Yethal created [Add parsers for cpuinfo and dmidecode](https://github.com/nushell/nu_scripts/pull/393), and [Create to-ini.nu](https://github.com/nushell/nu_scripts/pull/386)
- Kinchkun created [job.nu: update view source usage](https://github.com/nushell/nu_scripts/pull/392)
- baehyunsol created [make `up.nu` much simpler](https://github.com/nushell/nu_scripts/pull/391), and [remove `build-string`, which is deprecated](https://github.com/nushell/nu_scripts/pull/390)

## reedline

- sholderbach created [Apply clippy lints](https://github.com/nushell/reedline/pull/551), and [Bump version for `0.17.0` release](https://github.com/nushell/reedline/pull/550), and [Update `nu-ansi-term` to 0.47.0](https://github.com/nushell/reedline/pull/549)
- merelymyself created [allow reedline ctrl+o to take editor arguments](https://github.com/nushell/reedline/pull/544)
