---
title: Nushell 0.78
author: The Nu Authors
author_site: https://twitter.com/nu_shell
author_image: https://www.nushell.sh/blog/images/nu_logo.png
excerpt: Today, we're releasing version 0.78 of Nu. This release adds pattern matching, speed improvements, easier cell paths when columns may be missing, better error handling, and much more.
---

# Nushell 0.78

Nushell, or Nu for short, is a new shell that takes a modern, structured approach to your command line. It works seamlessly with the data from your filesystem, operating system, and a growing number of file formats to make it easy to build powerful command line pipelines.

Today, we're releasing version 0.78 of Nu. This release adds pattern matching, speed improvements, easier cell paths when columns may be missing, better error handling, and much more.

<!-- more -->

# Where to get it

Nu 0.78 is available as [pre-built binaries](https://github.com/nushell/nushell/releases/tag/0.78.0) or from [crates.io](https://crates.io/crates/nu). If you have Rust installed you can install it using `cargo install nu`.

NOTE: The optional dataframe functionality is available by `cargo install nu --features=dataframe`.

As part of this release, we also publish a set of optional plugins you can install and use with Nu. To install, use `cargo install nu_plugin_<plugin name>`.

# Themes of this release / New features

## Pattern matching (jt)

With 0.78, Nushell now comes with the `match` expression, which allows you to do pattern matching on a value. It supports a variety of different kinds of patterns, which can be mixed and matched to create more complicated patterns.

A simple example matching against a constant or a range:

```
match 3 {
  1 => { print "it's a 1" }
  1..10 => { print "it's between 1 and 10" }
}
```

Another example, this time matching against a record value, with a fall-through if it doesn't match:

```
match $a {
  {x: $x, y: 10} => { print $"y is: 10 and x is: ($x)" }
  _ => { print "the above didn't match, so we print this instead" }
}
```

You can also match on the elements of a list:

```
match $list {
  [$one] => { print "one element list" }
  [$one, $two] => { print "two element list" }
  [$head, ..$tail] => { print $"the tail of the list is ($tail)" }
}
```

## Alias changes ([kubouch](https://github.com/nushell/nushell/pull/8557))

### Aliases now can shadow 

We've updated the new `alias` command we introduced in 0.77 to work more closely to the previous one. For example:
```bash
> alias l = ls -a
> alias l = ls -l
```

Will now create the `l` alias that points to `ls -l`, with most recent line getting precedence during alias expansion.

### Alias can be named the same as the aliased command

```bash
> alias ls = ls -a
```

Now correctly displays all files when calling `ls`, instead of throwing an unhelpful error.

### Old alias still keeps working

Since there are still some remaining issues to fix with the new alias implementation, we still keep `old-alias` around for this release.

## Speed improvements ([jt](https://github.com/nushell/nushell/pull/8609))

We've sped up the performance of tight loops like `for` and `while` considerably in this release. For example, on our test machine:

Example 1: `timeit { for x in 1..1000000 {} }`

- 0.77.1: 908ms
- 0.78.0: 52ms

Example 2: `timeit { mut x = 1; while $x < 1000000 { $x += 1 } }`

- 0.77.1: 1082ms
- 0.78.0: 170ms

## Optional cell path members ([rgwood](https://github.com/nushell/nushell/pull/8379))

In Nu 0.78, you can use `?` in cell paths to suppress errors from missing data. `?` is a more convenient+powerful version of the `-i`/`--ignore-errors` flag on `get` and `select`. Here are some examples:

```bash
{ foo: 123 }.bar # errors because `bar` is not present on the record
{ foo: 123 }.bar? # returns null

{ foo: 123 } | get bar # errors
{ foo: 123 } | get bar? # returns null

{ foo: 123 }.bar.baz # errors
{ foo: 123 }.bar.baz? # errors because `bar` is not present
{ foo: 123 }.bar?.baz # returns null even though `baz` is not present; `?` short-circuits
{ foo: 123 }.bar?.baz? # returns null

[1, 2, 3].8 # errors because there is no 8th item in the list
[1, 2, 3].8? # returns null

[{foo: 123}, {}].foo # errors because `foo` is not present on every item in the table
[{foo: 123}, {}].foo? # returns a list [123, null]
```

`?` works anywhere that cell paths work, including `where`:

```
> [{foo: 123}, {}] | where foo? == 123
╭───┬─────╮
│ # │ foo │
├───┼─────┤
│ 0 │ 123 │
╰───┴─────╯
```

## better error handling in `error make` (`amtoine` in [#8511](https://github.com/nushell/nushell/pull/8511) and [#8570](https://github.com/nushell/nushell/pull/8570))

The `error make` command now gives better hints about why the format is not a valid `error make` format:

- with an empty format, `error make {}` will say that there is a "_missing required member `$.msg`_"
- with an empty `$.label`, `error make {msg: "message", label: {}}` will say there is a "_missing required member `$.label.text`_"
- finally, when `$.label.start` / `$.label.end` is not defined while the other is, `error make` will give a hint as to add the missing one to the format!

The second change disallow the use of a `$.label.start` greater than `$.label.end` as a span.

## Support for pretty output format in `to nuon` ([amtoine](https://github.com/nushell/nushell/pull/8366))

The `to nuon` command can now output _pretty_ NUON data with whitespaces for better readability.

The default behaviour still is to output everything on a single line, encouraging users to leverage the compactness of the NUON data format.

However, we can now output formatted NUON data with the `--indent` and `--tabs` options:

```bash
> [1 2 3] | to nuon --indent 4
[
    1,
    2,
    3
]
```

or

```bash
> {date: 2000-01-01, data: [1 [2 3] 4.56]} | to nuon --indent 4
{
    date: 2000-01-01T00:00:00+00:00,
    data: [
        1,
        [
            2,
            3
        ],
        4.56
    ]
}
```

The default _single-line_ behaviour still can be enforced with the `--raw` option, e.g.

```bash
> {date: 2000-01-01, data: [1 [2 3] 4.56]} | to nuon --indent 4 --raw
{date: 2000-01-01T00:00:00+00:00, data: [1, [2, 3], 4.56]}
```

## New `math exp` command ([lesves](https://github.com/nushell/nushell/pull/8700))

To complement the `math ln` command, we now include a `math exp` command for exponentiation with the base e.

# Breaking changes

## `let` requires surrounding parentheses for saving command output

`let x = ls` will not run the `ls` command anymore. If you need to save the output of a command, you need to wrap it in parentheses: `let x = (ls)`.

## `||` now required in closures

To help differentiate between blocks (which can mutate variables) and closures (which can be used in a pipeline), we've changed the syntax of closures to require `||`. This means the simplest closure now looks like `{|| }`

## We no longer automatically print values as part of a script

We've changed the automatic-printing rules for scripts and the REPL to now only automatically print the last value. This means two major breaking changes:

- We no longer [automatically print loop values](https://github.com/nushell/nushell/pull/8618)
- We no longer [print the results of every line automatically, requiring you to do it manually](https://github.com/nushell/nushell/pull/8292)

## Bare words can't start with a number

Words that start with a number or are in some way number-like must [now must be wrapped in backticks to be treated at a bare word or wrapped in quotes to be a string](https://github.com/nushell/nushell/pull/8635).

## Fields can only be defined once

You can no longer [redefine a field in a record during initialization](https://github.com/nushell/nushell/pull/8705)

## Thread configuration moves to `par-each`

Nushell no longer accepts the [-t/--threads flag to the binary as it's now part of `par-each`](https://github.com/nushell/nushell/pull/8686)

## Ranges become the standard range specifier

`str substring` now [only accepts ranges](https://github.com/nushell/nushell/pull/8660) as does [`bytes at`](https://github.com/nushell/nushell/pull/8710).

## Alias recursion has been disabled

Alias recursion is [now disabled](https://github.com/nushell/nushell/pull/8557)

## Empty lists handled more consistently

`[] | select foo` [now returns an empty list instead of `null`](https://github.com/nushell/nushell/pull/8651) and `sort`, `uniq`, `sort-by`, and `uniq-by` [now return empty lists when given an empty list](https://github.com/nushell/nushell/pull/8669) (previously they would throw an error)

These changes make it easier to work with lists of unknown size.

## Comparison operators now allow null

Previously expressions like `1 < null` would error; [now they return `null`](https://github.com/nushell/nushell/pull/8617).

# Full changelog

## Nushell

- sholderbach created [Pin `reedline` to `0.18.0` release](https://github.com/nushell/nushell/pull/8728), and [Fix rest of license year ranges](https://github.com/nushell/nushell/pull/8727), and [Remove unused `atty` dep in `nu-table`](https://github.com/nushell/nushell/pull/8716), and [Bump version to `0.78.0`](https://github.com/nushell/nushell/pull/8715), and [Fix two stable `clippy` lints](https://github.com/nushell/nushell/pull/8712), and [Remove `proptest`s for nuon writing/parsing](https://github.com/nushell/nushell/pull/8688), and [Add `CONTRIBUTING` section on PRs and git](https://github.com/nushell/nushell/pull/8521)
- fdncred created [Update .gitignore](https://github.com/nushell/nushell/pull/8717), and [fix test_default_config_path test after pr 8653](https://github.com/nushell/nushell/pull/8690), and [fully deprecate str collect](https://github.com/nushell/nushell/pull/8680), and [add a `threads` parameter to `par_each`](https://github.com/nushell/nushell/pull/8679), and [fix `inspect` panic with large tables](https://github.com/nushell/nushell/pull/8673), and [auto-expand paths in the `$nu` variable](https://github.com/nushell/nushell/pull/8653), and [allow startup-time to be captured when starting nushell with `nu -c`](https://github.com/nushell/nushell/pull/8599), and [tweak logging format](https://github.com/nushell/nushell/pull/8588), and [Clarify how `register` works](https://github.com/nushell/nushell/pull/8583), and [use reedline main branch](https://github.com/nushell/nushell/pull/8580), and [fixes the ability to have multiple modifiers on keybindings](https://github.com/nushell/nushell/pull/8579), and [make std.nu tests work on mac](https://github.com/nushell/nushell/pull/8576), and [Revert "Allow NU_LIBS_DIR and friends to be const"](https://github.com/nushell/nushell/pull/8501)
- harshalchaudhari35 created [Fix(tests/nu-command): remove unnecessary cwd() and pipeline(), etc](https://github.com/nushell/nushell/pull/8711)
- 1Kinoti created [make `bytes at` use ranges](https://github.com/nushell/nushell/pull/8710), and [fix unhelpful error message with '@' custom completion](https://github.com/nushell/nushell/pull/8620), and [fix unhelpful error message with extra characters in list annotations](https://github.com/nushell/nushell/pull/8619), and [type-check default values of list annotations](https://github.com/nushell/nushell/pull/8600), and [unify the `run` functions of `all` and `any`](https://github.com/nushell/nushell/pull/8578), and [fix: `bytes length` example description typo](https://github.com/nushell/nushell/pull/8550), and [allow lists to have type annotations](https://github.com/nushell/nushell/pull/8529)
- jntrnr created [give better error when a numberlike is used for strings](https://github.com/nushell/nushell/pull/8706), and [prevent redefining fields in a record](https://github.com/nushell/nushell/pull/8705), and [Add rest and ignore-rest patterns](https://github.com/nushell/nushell/pull/8681), and [Remove CI coverage until we can figure out why it's broken](https://github.com/nushell/nushell/pull/8677), and [move 'str substring' to only use ranges](https://github.com/nushell/nushell/pull/8660), and [Improve inferred record types and type compat](https://github.com/nushell/nushell/pull/8649), and [Improve number-like error if expecting a string](https://github.com/nushell/nushell/pull/8645), and [Require that values that look like numbers parse as numberlike](https://github.com/nushell/nushell/pull/8635), and [Add or-patterns, fix var binding scope](https://github.com/nushell/nushell/pull/8633), and [Remove autoprinting of loop block values](https://github.com/nushell/nushell/pull/8618), and [Speed up tight loop benchmarks](https://github.com/nushell/nushell/pull/8609), and [Add more pattern types to matcher](https://github.com/nushell/nushell/pull/8605), and [Move variables to var stack](https://github.com/nushell/nushell/pull/8604), and [Fix closures that use matches. Move 'collect' to core.](https://github.com/nushell/nushell/pull/8596), and [Make timeit work with command calls](https://github.com/nushell/nushell/pull/8594), and [Move timeit to use blocks. Make match vars immutable](https://github.com/nushell/nushell/pull/8592), and [Add pattern matching](https://github.com/nushell/nushell/pull/8590), and [Switch let/let-env family to init with math expressions](https://github.com/nushell/nushell/pull/8545), and [Fix command missing hook default config](https://github.com/nushell/nushell/pull/8540), and [Add rest and glob support to 'open'](https://github.com/nushell/nushell/pull/8506), and [bump to 0.77.2](https://github.com/nushell/nushell/pull/8496)
- amtoine created [move the `show_banner` config field to the top](https://github.com/nushell/nushell/pull/8702), and [REFACTOR: remove the redundant `path expand` from the tests of the standard library](https://github.com/nushell/nushell/pull/8666), and [stdlib: fix the `assert equal` tests](https://github.com/nushell/nushell/pull/8650), and [feature: add the standard library tests to the PR template and the toolkit](https://github.com/nushell/nushell/pull/8629), and [stdlib: optimize test search and add better errors](https://github.com/nushell/nushell/pull/8626), and [remove `match` from the standard library](https://github.com/nushell/nushell/pull/8625), and [FIX: do not allow *start > end* in `error make` spans](https://github.com/nushell/nushell/pull/8570), and [FIX: expand all the `base_path`s in `std::test_dirs`](https://github.com/nushell/nushell/pull/8552), and [standard library: fix the readme](https://github.com/nushell/nushell/pull/8526), and [standard library: bring the tests into the main CI](https://github.com/nushell/nushell/pull/8525), and [FEATURE: write better errors for `error make` and complete the doc](https://github.com/nushell/nushell/pull/8511), and [standard library: use the standard assert and fix test output](https://github.com/nushell/nushell/pull/8509), and [standard library: fix the tests for the new closure parsing of `0.77.2`](https://github.com/nushell/nushell/pull/8504)
- lesves created [Add `math exp` command (issue #8661)](https://github.com/nushell/nushell/pull/8700)
- rgwood created [Make optional cell paths work with `reject`](https://github.com/nushell/nushell/pull/8697), and [Remove `-t`/`--threads` flag from nu](https://github.com/nushell/nushell/pull/8686), and [Fix record-to-JSON conversion for HTTP commands](https://github.com/nushell/nushell/pull/8663), and [Fix `select` on empty lists](https://github.com/nushell/nushell/pull/8651), and [Change comparison operators to allow nulls](https://github.com/nushell/nushell/pull/8617), and [Clean up unnecessary macro use](https://github.com/nushell/nushell/pull/8607), and [Make HTTP requests cancellable when trying to connect](https://github.com/nushell/nushell/pull/8591), and [Better error message for `mv` when file not found](https://github.com/nushell/nushell/pull/8586), and [Cell paths: make optional path members short-circuit](https://github.com/nushell/nushell/pull/8554)
- kks110 created [Fix a bug with `us` not outputting as `µs` with the `into duration` command](https://github.com/nushell/nushell/pull/8691), and [Allow parsing of mu (µ) character for durations (issue #8614)](https://github.com/nushell/nushell/pull/8647)
- zhiburt created [Fix of a fix of #8671](https://github.com/nushell/nushell/pull/8675)
- Benjamin-L created [Support passing an empty list to sort, uniq, sort-by, and uniq-by (issue #5957)](https://github.com/nushell/nushell/pull/8669)
- stormasm created [one more try on readme](https://github.com/nushell/nushell/pull/8659), and [Add the showcase repo to Readme.md to give it more exposure to our developers](https://github.com/nushell/nushell/pull/8658), and [remove unused imports: `Deserialize`, `Serialize` compiler warning for nu-protocol/src/example.rs](https://github.com/nushell/nushell/pull/8514)
- presidento created [stdlib: Add back recursive lookup for tests](https://github.com/nushell/nushell/pull/8632), and [stdlib: Implement common assert commands](https://github.com/nushell/nushell/pull/8515), and [std lib: extend test runner capabilities](https://github.com/nushell/nushell/pull/8499)
- dependabot[bot] created [Bump openssl from 0.10.45 to 0.10.48](https://github.com/nushell/nushell/pull/8606), and [Bump actions-rust-lang/setup-rust-toolchain from 1.4.3 to 1.4.4](https://github.com/nushell/nushell/pull/8536), and [Bump windows from 0.44.0 to 0.46.0](https://github.com/nushell/nushell/pull/8535), and [Bump rstest from 0.16.0 to 0.17.0](https://github.com/nushell/nushell/pull/8534), and [Bump quick-xml from 0.27.1 to 0.28.1](https://github.com/nushell/nushell/pull/8533), and [Bump alphanumeric-sort from 1.4.4 to 1.5.0](https://github.com/nushell/nushell/pull/8532), and [Bump miette from 5.5.0 to 5.6.0](https://github.com/nushell/nushell/pull/8531)
- StevenDoesStuffs created [Fix mode tests which use sh to not run on windows](https://github.com/nushell/nushell/pull/8601)
- Sygmei created [feat: added multiple options to http commands](https://github.com/nushell/nushell/pull/8571)
- jaudiger created [Remove once_cell dependency from nu-test-support create.](https://github.com/nushell/nushell/pull/8568)
- WindSoilder created [better error message if plugin name doesn't starts with `nu_plugin_`](https://github.com/nushell/nushell/pull/8562), and [When running external command, expand tilde when pass back-quoted word](https://github.com/nushell/nushell/pull/8561)
- stevenxxiu created [fix: set `repl_buffer_state` to the REPL buffer after the `pre_execut…](https://github.com/nushell/nushell/pull/8560)
- hyiltiz created [Fix nu build script since for loops are stateful now](https://github.com/nushell/nushell/pull/8559)
- friedow created [from ssv --aligned-columns should separate lines by character index instead of byte index](https://github.com/nushell/nushell/pull/8558)
- kubouch created [Disable alias recursion (for real)](https://github.com/nushell/nushell/pull/8557)
- dandavison created [Short redirection syntax](https://github.com/nushell/nushell/pull/8503)
- NotLebedev created [Revert "Hide 7925"](https://github.com/nushell/nushell/pull/8500)
- jntrnr created [parser: Add cell path literal syntax](https://github.com/nushell/nushell/pull/8493), and [parser: Fix panic that happens when you type a single `{`](https://github.com/nushell/nushell/pull/8492), and [Fix CI tests that landed after no-implicit-echo](https://github.com/nushell/nushell/pull/8491), and [Fix parse of def with paren params](https://github.com/nushell/nushell/pull/8490), and [Escape will now escape paths with '=' in them](https://github.com/nushell/nushell/pull/8485), and [Start grouping parsing of values better](https://github.com/nushell/nushell/pull/8470)
- amtoine created [REFACTOR: put all the standard library in `std.nu`](https://github.com/nushell/nushell/pull/8489), and [DOC: make the README of the standard library clearer](https://github.com/nushell/nushell/pull/8465), and [FEATURE: add a pretty output to `toolkit check pr`](https://github.com/nushell/nushell/pull/8416), and [FEATURE: add `--raw`. `--tabs` and `--indent` to `to nuon` as in `to json`](https://github.com/nushell/nushell/pull/8366)
- rgwood created [Add `-i` flag back to `get` and `select`](https://github.com/nushell/nushell/pull/8488), and [Optional members in cell paths: Attempt 2](https://github.com/nushell/nushell/pull/8379)
- bgeron created [Exit successfully from `nu --help` for compatibility with halp](https://github.com/nushell/nushell/pull/8478)
- hustcer created [Fix docs building error caused by missing end tag](https://github.com/nushell/nushell/pull/8477)
- WindSoilder created [Revert "Throw out error if external command in subexpression is failed to run (#8204)"](https://github.com/nushell/nushell/pull/8475), and [make better usage of error value in `catch` block](https://github.com/nushell/nushell/pull/8460), and [Restrict closure expression to be something like `{|| ...}`](https://github.com/nushell/nushell/pull/8290), and [make `else if` generate helpful error when condition have an issue](https://github.com/nushell/nushell/pull/8274)
- lucperkins created [Add char --list example to char command docs](https://github.com/nushell/nushell/pull/8474)
- presidento created [Make assert eq, assert ne consistent with ==, != operators](https://github.com/nushell/nushell/pull/8473), and [standard library: add log commands](https://github.com/nushell/nushell/pull/8448), and [stdlib: add test discovery, extract test files](https://github.com/nushell/nushell/pull/8443)
- nicokosi created [docs: Use capital letters for CSV and JSON acronyms](https://github.com/nushell/nushell/pull/8459)
- dependabot[bot] created [Bump mockito from 0.32.5 to 1.0.0](https://github.com/nushell/nushell/pull/8426)
- dandavison created [SQL-style join command for Nushell tables](https://github.com/nushell/nushell/pull/8424)
- mdeville created [Additional flags for commands `from csv` and `from tsv`](https://github.com/nushell/nushell/pull/8398)
- kubouch created [Add proptest regression](https://github.com/nushell/nushell/pull/8396)
- uaeio created [Decode and Encode hex](https://github.com/nushell/nushell/pull/8392)
- fdncred created [enable error reporting from enable_vt_processing](https://github.com/nushell/nushell/pull/8373)
- initinll created [Added fix for bug #8278 to read tag values from YAML files](https://github.com/nushell/nushell/pull/8354)
- Sygmei created [fix: fixed typo and improved Value TypeMismatch exceptions](https://github.com/nushell/nushell/pull/8324)
- stevenxxiu created [feat: add a `command_not_found` hook](https://github.com/nushell/nushell/pull/8314), and [fix: fix `commandline` when called with no arguments](https://github.com/nushell/nushell/pull/8207)
- StevenDoesStuffs created [Allow NU_LIBS_DIR and friends to be const](https://github.com/nushell/nushell/pull/8310)
- NotLebedev created [Disable pipeline echo](https://github.com/nushell/nushell/pull/8292)
- alesito85 created [Ls symlink fix](https://github.com/nushell/nushell/pull/8276)

## Extension

- fdncred created [fix `use` when it's used in variable name](https://github.com/nushell/vscode-nushell-lang/pull/86)

## Documentation

- pingiun created [Remove mention of 'env' command in environment.md](https://github.com/nushell/nushell.github.io/pull/854), and [Remove old 'env' command from configuration section](https://github.com/nushell/nushell.github.io/pull/853)
- hustcer created [fix #850, make `make_docs.nu` work for nu v0.77.2+](https://github.com/nushell/nushell.github.io/pull/851), and [Update plugin docs for v0.77](https://github.com/nushell/nushell.github.io/pull/831)
- amtoine created [add a note about better `error make`](https://github.com/nushell/nushell.github.io/pull/849), and [add #8366 to the release notes](https://github.com/nushell/nushell.github.io/pull/848), and [add a note about "value / description" completion](https://github.com/nushell/nushell.github.io/pull/838)
- fdncred created [change `let config` to `let-env config`](https://github.com/nushell/nushell.github.io/pull/844), and [show the list of combined keybinding modifiers](https://github.com/nushell/nushell.github.io/pull/840)
- stevenxxiu created [feat: docs on the `command_not_found` hook](https://github.com/nushell/nushell.github.io/pull/843)
- presidento created [Add chapter about testing in Nushell](https://github.com/nushell/nushell.github.io/pull/839)
- petrisch created [DE translation for command_signature](https://github.com/nushell/nushell.github.io/pull/837), and [DE translation for overlays](https://github.com/nushell/nushell.github.io/pull/832)
- thomasgoulet created [Add context aware custom completions to the book](https://github.com/nushell/nushell.github.io/pull/836)
- alurm created [Fix typos in book/stdout_stderr_exit_codes.md](https://github.com/nushell/nushell.github.io/pull/835)
- aidalgol created [Add "Coming from Bash" entries for discarding command output](https://github.com/nushell/nushell.github.io/pull/834)

## Nu_Scripts

- fdncred created [replace occurences of `str collect` with `str join`](https://github.com/nushell/nu_scripts/pull/436), and [update to new nushell syntax](https://github.com/nushell/nu_scripts/pull/430), and [update script syntax to match the latest nushell](https://github.com/nushell/nu_scripts/pull/429), and [Update CODEOWNERS](https://github.com/nushell/nu_scripts/pull/428), and [updated some scripts to support the latest changes in 0.77.1](https://github.com/nushell/nu_scripts/pull/416)
- fj0r created [add parameters default value to just's completion and `j` for shortcut](https://github.com/nushell/nu_scripts/pull/435), and [dp for `docker ps` support docker and podman](https://github.com/nushell/nu_scripts/pull/421)
- WindSoilder created [Replace `str collect` with `str join`](https://github.com/nushell/nu_scripts/pull/434), and [fix conda script](https://github.com/nushell/nu_scripts/pull/424)
- jntrnr created [Update TWiN and since last release to 0.78](https://github.com/nushell/nu_scripts/pull/433)
- lesves created [Removed `math exp`, it is now built-in](https://github.com/nushell/nu_scripts/pull/432)
- ankitgahlyan created [typo](https://github.com/nushell/nu_scripts/pull/431)
- spitfire05 created [Add gpsup, glo, git_current_branch](https://github.com/nushell/nu_scripts/pull/426), and [Add `gmom` alias; add missing `git_main_branch` function](https://github.com/nushell/nu_scripts/pull/425)
- davidlattimore created [git-completions: Add completions for more subcommands](https://github.com/nushell/nu_scripts/pull/420)
- Hofer-Julian created [Add CODEOWNERS file](https://github.com/nushell/nu_scripts/pull/419), and [conda: Disable prompt via env var instead of flag](https://github.com/nushell/nu_scripts/pull/417)
- sgasse created [custom-completions: git: Include remote branches](https://github.com/nushell/nu_scripts/pull/407)
- amtoine created [FIX: define a `main` function to `use` the themes modules](https://github.com/nushell/nu_scripts/pull/402)
- sholderbach created [Fix `since_last_release.nu` script](https://github.com/nushell/nu_scripts/pull/385)

## reedline

- sholderbach created [Bump version for `0.18.0` release](https://github.com/nushell/reedline/pull/564)
- fdncred created [show the ability to have multiple modifiers](https://github.com/nushell/reedline/pull/559)
- Hofer-Julian created [Check typos in CI](https://github.com/nushell/reedline/pull/557)
- jaudiger created [Add const to some new functions.](https://github.com/nushell/reedline/pull/555), and [Set MSRV to 1.62.1](https://github.com/nushell/reedline/pull/554)
- ryanwhitehouse created [Allow multi byte characters as the marker without panicking](https://github.com/nushell/reedline/pull/553)
